# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_client_objects.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.enums_pb2 as enums__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"steammessages_client_objects.proto\x1a\x0b\x65nums.proto\"\xcb\x02\n0SteamMessagesClientIClientForcedEnumDependencies\x12?\n\x01\x61\x18\x01 \x01(\x0e\x32\x15.EBluetoothDeviceType:\x1dk_BluetoothDeviceType_Invalid\x12H\n\x01\x62\x18\x02 \x01(\x0e\x32\x19.EStorageBlockContentType:\"k_EStorageBlockContentType_Invalid\x12N\n\x01\x63\x18\x03 \x01(\x0e\x32\x1c.EStorageBlockFileSystemType:%k_EStorageBlockFileSystemType_Invalid\x12<\n\x01\x64\x18\x04 \x01(\x0e\x32\x13.ESDCardFormatStage:\x1ck_ESDCardFormatStage_Invalid\"=\n\x1b\x43MsgNetworkDeviceIP4Address\x12\r\n\x02ip\x18\x01 \x01(\x05:\x01\x30\x12\x0f\n\x07netmask\x18\x02 \x01(\x05\"\xbf\x01\n\x1a\x43MsgNetworkDeviceIP4Config\x12/\n\taddresses\x18\x01 \x03(\x0b\x32\x1c.CMsgNetworkDeviceIP4Address\x12\x0e\n\x06\x64ns_ip\x18\x02 \x03(\x05\x12\x12\n\ngateway_ip\x18\x03 \x01(\x05\x12\x17\n\x0fis_dhcp_enabled\x18\x04 \x01(\x08\x12\x18\n\x10is_default_route\x18\x05 \x01(\x08\x12\x19\n\nis_enabled\x18\x06 \x01(\x08:\x05\x66\x61lse\")\n\x1b\x43MsgNetworkDeviceIP6Address\x12\n\n\x02ip\x18\x01 \x01(\t\"\xbf\x01\n\x1a\x43MsgNetworkDeviceIP6Config\x12/\n\taddresses\x18\x01 \x03(\x0b\x32\x1c.CMsgNetworkDeviceIP6Address\x12\x0e\n\x06\x64ns_ip\x18\x02 \x03(\t\x12\x12\n\ngateway_ip\x18\x03 \x01(\t\x12\x17\n\x0fis_dhcp_enabled\x18\x04 \x01(\x08\x12\x18\n\x10is_default_route\x18\x05 \x01(\x08\x12\x19\n\nis_enabled\x18\x06 \x01(\x08:\x05\x66\x61lse\"\x97\x06\n\x16\x43MsgNetworkDevicesData\x12/\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32\x1e.CMsgNetworkDevicesData.Device\x12\x17\n\x0fis_wifi_enabled\x18\x02 \x01(\x08\x12 \n\x18is_wifi_scanning_enabled\x18\x03 \x01(\x08\x1a\x90\x05\n\x06\x44\x65vice\x12\r\n\x02id\x18\x01 \x01(\r:\x01\x30\x12\r\n\x05\x65type\x18\x02 \x01(\x05\x12\x0e\n\x06\x65state\x18\x03 \x01(\x05\x12\x0b\n\x03mac\x18\x04 \x01(\t\x12\x0e\n\x06vendor\x18\x05 \x01(\t\x12\x0f\n\x07product\x18\x06 \x01(\t\x12(\n\x03ip4\x18\x07 \x01(\x0b\x32\x1b.CMsgNetworkDeviceIP4Config\x12(\n\x03ip6\x18\x08 \x01(\x0b\x32\x1b.CMsgNetworkDeviceIP6Config\x12\x33\n\x05wired\x18\t \x01(\x0b\x32$.CMsgNetworkDevicesData.Device.Wired\x12\x39\n\x08wireless\x18\n \x01(\x0b\x32\'.CMsgNetworkDevicesData.Device.Wireless\x1aS\n\x05Wired\x12\x1f\n\x10is_cable_present\x18\x01 \x01(\x08:\x05\x66\x61lse\x12\x12\n\nspeed_mbit\x18\x02 \x01(\r\x12\x15\n\rfriendly_name\x18\x03 \x01(\t\x1a\x90\x02\n\x08Wireless\x12\x37\n\x03\x61ps\x18\x01 \x03(\x0b\x32*.CMsgNetworkDevicesData.Device.Wireless.AP\x12\x1b\n\x13\x65security_supported\x18\x02 \x01(\x05\x1a\xad\x01\n\x02\x41P\x12\r\n\x02id\x18\x01 \x01(\r:\x01\x30\x12\x11\n\testrength\x18\x02 \x01(\x05\x12\x0c\n\x04ssid\x18\x03 \x01(\t\x12\x11\n\tis_active\x18\x04 \x01(\x08\x12\x16\n\x0eis_autoconnect\x18\x05 \x01(\x08\x12\x11\n\tesecurity\x18\x06 \x01(\x05\x12\x11\n\tuser_name\x18\x07 \x01(\t\x12\x10\n\x08password\x18\x08 \x01(\t\x12\x14\n\x0cstrength_raw\x18\t \x01(\x05\"\xb5\x03\n\x18\x43MsgNetworkDeviceConnect\x12\x14\n\tdevice_id\x18\x01 \x01(\r:\x01\x30\x12:\n\x0b\x63redentials\x18\x04 \x01(\x0b\x32%.CMsgNetworkDeviceConnect.Credentials\x12(\n\x03ip4\x18\x05 \x01(\x0b\x32\x1b.CMsgNetworkDeviceIP4Config\x12(\n\x03ip6\x18\x06 \x01(\x0b\x32\x1b.CMsgNetworkDeviceIP6Config\x12\x35\n\x08\x61p_known\x18\x02 \x01(\x0b\x32!.CMsgNetworkDeviceConnect.KnownAPH\x00\x12\x37\n\tap_custom\x18\x03 \x01(\x0b\x32\".CMsgNetworkDeviceConnect.CustomAPH\x00\x1a\x18\n\x07KnownAP\x12\r\n\x05\x61p_id\x18\x01 \x01(\r\x1a+\n\x08\x43ustomAP\x12\x0c\n\x04ssid\x18\x01 \x01(\t\x12\x11\n\tesecurity\x18\x02 \x01(\x05\x1a\x31\n\x0b\x43redentials\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\tB\t\n\x07\x61p_info\"\x9f\x06\n\x16\x43MsgStorageDevicesData\x12-\n\x06\x64rives\x18\x01 \x03(\x0b\x32\x1d.CMsgStorageDevicesData.Drive\x12:\n\rblock_devices\x18\x02 \x03(\x0b\x32#.CMsgStorageDevicesData.BlockDevice\x12\x1c\n\x14is_unmount_supported\x18\x03 \x01(\x08\x12\x19\n\x11is_trim_supported\x18\x04 \x01(\x08\x12\x17\n\x0fis_trim_running\x18\x05 \x01(\x08\x1a\xbe\x01\n\x05\x44rive\x12\r\n\x02id\x18\x01 \x01(\r:\x01\x30\x12\r\n\x05model\x18\x02 \x01(\t\x12\x0e\n\x06vendor\x18\x03 \x01(\t\x12\x0e\n\x06serial\x18\x04 \x01(\t\x12\x14\n\x0cis_ejectable\x18\x05 \x01(\x08\x12\x12\n\nsize_bytes\x18\x06 \x01(\x04\x12M\n\nmedia_type\x18\x07 \x01(\x0e\x32\x17.EStorageDriveMediaType: k_EStorageDriveMediaType_Invalid\x1a\x86\x03\n\x0b\x42lockDevice\x12\r\n\x02id\x18\x01 \x01(\r:\x01\x30\x12\x13\n\x08\x64rive_id\x18\x02 \x01(\r:\x01\x30\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x15\n\rfriendly_path\x18\x04 \x01(\t\x12\r\n\x05label\x18\x05 \x01(\t\x12\x12\n\nsize_bytes\x18\x06 \x01(\x04\x12\x16\n\x0eis_formattable\x18\x07 \x01(\x08\x12\x14\n\x0cis_read_only\x18\x08 \x01(\x08\x12\x16\n\x0eis_root_device\x18\t \x01(\x08\x12S\n\x0c\x63ontent_type\x18\n \x01(\x0e\x32\x19.EStorageBlockContentType:\"k_EStorageBlockContentType_Invalid\x12\\\n\x0f\x66ilesystem_type\x18\x0b \x01(\x0e\x32\x1c.EStorageBlockFileSystemType:%k_EStorageBlockFileSystemType_Invalid\x12\x12\n\nmount_path\x18\x0c \x01(\t\"\xdf\x01\n\x1d\x43\x43loud_PendingRemoteOperation\x12T\n\toperation\x18\x01 \x01(\x0e\x32\x1d.ECloudPendingRemoteOperation:\"k_ECloudPendingRemoteOperationNone\x12\x14\n\x0cmachine_name\x18\x02 \x01(\t\x12\x11\n\tclient_id\x18\x03 \x01(\x04\x12\x19\n\x11time_last_updated\x18\x04 \x01(\r\x12\x0f\n\x07os_type\x18\x05 \x01(\x05\x12\x13\n\x0b\x64\x65vice_type\x18\x06 \x01(\x05\"V\n CMsgCloudPendingRemoteOperations\x12\x32\n\noperations\x18\x01 \x03(\x0b\x32\x1e.CCloud_PendingRemoteOperation\"\xdf\x04\n\x18\x43MsgBluetoothDevicesData\x12\x33\n\x08\x61\x64\x61pters\x18\x01 \x03(\x0b\x32!.CMsgBluetoothDevicesData.Adapter\x12\x31\n\x07\x64\x65vices\x18\x02 \x03(\x0b\x32 .CMsgBluetoothDevicesData.Device\x12\x32\n\x07manager\x18\x03 \x01(\x0b\x32!.CMsgBluetoothDevicesData.Manager\x1a_\n\x07\x41\x64\x61pter\x12\r\n\x02id\x18\x01 \x01(\r:\x01\x30\x12\x0b\n\x03mac\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\nis_enabled\x18\x04 \x01(\x08\x12\x16\n\x0eis_discovering\x18\x05 \x01(\x08\x1a\x9c\x02\n\x06\x44\x65vice\x12\r\n\x02id\x18\x01 \x01(\r:\x01\x30\x12\x15\n\nadapter_id\x18\x02 \x01(\r:\x01\x30\x12\x43\n\x05\x65type\x18\x03 \x01(\x0e\x32\x15.EBluetoothDeviceType:\x1dk_BluetoothDeviceType_Invalid\x12\x0b\n\x03mac\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x14\n\x0cis_connected\x18\x06 \x01(\x08\x12\x11\n\tis_paired\x18\x07 \x01(\x08\x12\x14\n\x0cstrength_raw\x18\x08 \x01(\x05\x12\x14\n\x0cwake_allowed\x18\t \x01(\x08\x12\x1e\n\x16wake_allowed_supported\x18\n \x01(\x08\x12\x17\n\x0f\x62\x61ttery_percent\x18\x0b \x01(\x05\x1a\'\n\x07Manager\x12\x1c\n\x14is_bluetooth_enabled\x18\x01 \x01(\x08\"<\n\x1d\x43MsgSystemPerfDiagnosticEntry\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xa5\x01\n\x1e\x43MsgSystemPerfNetworkInterface\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x01\x12\x16\n\x0etx_bytes_total\x18\x03 \x01(\x03\x12\x16\n\x0erx_bytes_total\x18\x04 \x01(\x03\x12\x18\n\x10tx_bytes_per_sec\x18\x05 \x01(\x05\x12\x18\n\x10rx_bytes_per_sec\x18\x06 \x01(\x05\"\x9c\x01\n\x1c\x43MsgSystemPerfDiagnosticInfo\x12/\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x1e.CMsgSystemPerfDiagnosticEntry\x12\x33\n\ninterfaces\x18\x02 \x03(\x0b\x32\x1f.CMsgSystemPerfNetworkInterface\x12\x16\n\x0e\x62\x61ttery_temp_c\x18\x03 \x01(\x02\"\xaf\x07\n\x14\x43MsgSystemPerfLimits\x12#\n\x1b\x63pu_governor_manual_min_mhz\x18\x01 \x01(\x05\x12#\n\x1b\x63pu_governor_manual_max_mhz\x18\x02 \x01(\x05\x12\x19\n\x11\x66sr_sharpness_min\x18\x03 \x01(\x05\x12\x19\n\x11\x66sr_sharpness_max\x18\x04 \x01(\x05\x12&\n\x1egpu_performance_manual_min_mhz\x18\x05 \x01(\x05\x12&\n\x1egpu_performance_manual_max_mhz\x18\x06 \x01(\x05\x12\"\n\x1aperf_overlay_is_standalone\x18\x07 \x01(\x08\x12 \n\x18is_dynamic_vrs_available\x18\x08 \x01(\x08\x12\x30\n(is_manual_display_refresh_rate_available\x18\t \x01(\x08\x12?\n gpu_performance_levels_available\x18\n \x03(\x0e\x32\x15.EGPUPerformanceLevel\x12%\n\x1d\x64isplay_refresh_manual_hz_min\x18\x0b \x01(\x05\x12%\n\x1d\x64isplay_refresh_manual_hz_max\x18\x0c \x01(\x05\x12\x19\n\x11\x66ps_limit_options\x18\r \x03(\x05\x12\x15\n\rtdp_limit_min\x18\x0e \x01(\x05\x12\x15\n\rtdp_limit_max\x18\x0f \x01(\x05\x12.\n&display_external_refresh_manual_hz_min\x18\x13 \x01(\x05\x12.\n&display_external_refresh_manual_hz_max\x18\x14 \x01(\x05\x12\"\n\x1a\x66ps_limit_options_external\x18\x15 \x03(\x05\x12\x18\n\x10is_vrr_supported\x18\x17 \x01(\x08\x12\x32\n*is_dynamic_refresh_rate_in_steam_supported\x18\x18 \x01(\x08\x12=\n\x1fsplit_scaling_filters_available\x18\x1a \x03(\x0e\x32\x14.ESplitScalingFilter\x12=\n\x1fsplit_scaling_scalers_available\x18\x1b \x03(\x0e\x32\x14.ESplitScalingScaler\x12\'\n\x1f\x64isable_refresh_rate_management\x18\x1e \x01(\x08\"\xaf\x06\n\x1c\x43MsgSystemPerfSettingsGlobal\x12\x1e\n\x16\x64iagnostic_update_rate\x18\x01 \x01(\x02\x12[\n\x1asystem_trace_service_state\x18\x02 \x01(\x0e\x32\x14.ESystemServiceState:!k_ESystemServiceState_Unavailable\x12\x61\n graphics_profiling_service_state\x18\x03 \x01(\x0e\x32\x14.ESystemServiceState:!k_ESystemServiceState_Unavailable\x12[\n\x1aperf_overlay_service_state\x18\x04 \x01(\x0e\x32\x14.ESystemServiceState:!k_ESystemServiceState_Unavailable\x12Z\n\x12perf_overlay_level\x18\x05 \x01(\x0e\x32\x1a.EGraphicsPerfOverlayLevel:\"k_EGraphicsPerfOverlayLevel_Hidden\x12/\n\'is_show_perf_overlay_over_steam_enabled\x18\x06 \x01(\x08\x12$\n\x1cis_advanced_settings_enabled\x18\x07 \x01(\x08\x12.\n&allow_external_display_refresh_control\x18\x08 \x01(\x08\x12X\n\x1bhdr_on_sdr_tonemap_operator\x18\x0c \x01(\x0e\x32\x14.EHDRToneMapOperator:\x1dk_EHDRToneMapOperator_Invalid\x12$\n\x1cis_hdr_debug_heatmap_enabled\x18\r \x01(\x08\x12+\n\x1d\x66orce_hdr_wide_gammut_for_sdr\x18\x0f \x01(\x08:\x04true\x12\x1d\n\x15sdr_to_hdr_brightness\x18\x16 \x01(\x02\x12#\n\x1bis_color_management_enabled\x18\x15 \x01(\x08\"\x93\x07\n\x1c\x43MsgSystemPerfSettingsPerApp\x12\"\n\x1agpu_performance_manual_mhz\x18\x01 \x01(\x05\x12\x11\n\tfps_limit\x18\x02 \x01(\x05\x12&\n\x1eis_variable_resolution_enabled\x18\x03 \x01(\x08\x12\'\n\x1fis_dynamic_refresh_rate_enabled\x18\x04 \x01(\x08\x12\x11\n\ttdp_limit\x18\x05 \x01(\x05\x12;\n\x0c\x63pu_governor\x18\x06 \x01(\x0e\x32\r.ECPUGovernor:\x16k_ECPUGovernor_Invalid\x12\x1f\n\x17\x63pu_governor_manual_mhz\x18\x07 \x01(\x05\x12\x16\n\x0escaling_filter\x18\x08 \x01(\x05\x12\x15\n\rfsr_sharpness\x18\t \x01(\x05\x12\x1c\n\x14is_fps_limit_enabled\x18\n \x01(\x08\x12\x1c\n\x14is_tdp_limit_enabled\x18\x0b \x01(\x08\x12#\n\x1bis_low_latency_mode_enabled\x18\x0c \x01(\x08\x12!\n\x19\x64isplay_refresh_manual_hz\x18\r \x01(\x05\x12$\n\x1cis_game_perf_profile_enabled\x18\x0e \x01(\x08\x12T\n\x15gpu_performance_level\x18\x0f \x01(\x0e\x32\x15.EGPUPerformanceLevel:\x1ek_EGPUPerformanceLevel_Invalid\x12*\n\"display_external_refresh_manual_hz\x18\x11 \x01(\x05\x12\x1a\n\x12\x66ps_limit_external\x18\x12 \x01(\x05\x12\x1a\n\x12is_tearing_enabled\x18\x13 \x01(\x08\x12\x16\n\x0eis_vrr_enabled\x18\x14 \x01(\x08\x12)\n!use_dynamic_refresh_rate_in_steam\x18\x17 \x01(\x08\x12Q\n\x14split_scaling_filter\x18\x18 \x01(\x0e\x32\x14.ESplitScalingFilter:\x1dk_ESplitScalingFilter_Invalid\x12Q\n\x14split_scaling_scaler\x18\x19 \x01(\x0e\x32\x14.ESplitScalingScaler:\x1dk_ESplitScalingScaler_Invalid\"w\n\x16\x43MsgSystemPerfSettings\x12-\n\x06global\x18\x01 \x01(\x0b\x32\x1d.CMsgSystemPerfSettingsGlobal\x12.\n\x07per_app\x18\x02 \x01(\x0b\x32\x1d.CMsgSystemPerfSettingsPerApp\"\x8c\x08\n\x18\x43MsgSystemPerfSettingsV1\x12\x1e\n\x16\x64iagnostic_update_rate\x18\x01 \x01(\x02\x12[\n\x1asystem_trace_service_state\x18\x02 \x01(\x0e\x32\x14.ESystemServiceState:!k_ESystemServiceState_Unavailable\x12\x61\n graphics_profiling_service_state\x18\x03 \x01(\x0e\x32\x14.ESystemServiceState:!k_ESystemServiceState_Unavailable\x12[\n\x1aperf_overlay_service_state\x18\x04 \x01(\x0e\x32\x14.ESystemServiceState:!k_ESystemServiceState_Unavailable\x12Z\n\x12perf_overlay_level\x18\x05 \x01(\x0e\x32\x1a.EGraphicsPerfOverlayLevel:\"k_EGraphicsPerfOverlayLevel_Hidden\x12T\n\x15gpu_performance_level\x18\x06 \x01(\x0e\x32\x15.EGPUPerformanceLevel:\x1ek_EGPUPerformanceLevel_Invalid\x12\"\n\x1agpu_performance_manual_mhz\x18\x07 \x01(\x05\x12\x11\n\tfps_limit\x18\x08 \x01(\x05\x12&\n\x1eis_variable_resolution_enabled\x18\t \x01(\x08\x12\'\n\x1fis_dynamic_refresh_rate_enabled\x18\n \x01(\x08\x12\x11\n\ttdp_limit\x18\x0b \x01(\x05\x12;\n\x0c\x63pu_governor\x18\x0c \x01(\x0e\x32\r.ECPUGovernor:\x16k_ECPUGovernor_Invalid\x12\x1f\n\x17\x63pu_governor_manual_mhz\x18\r \x01(\x05\x12\x16\n\x0escaling_filter\x18\x0e \x01(\x05\x12\x15\n\rfsr_sharpness\x18\x0f \x01(\x05\x12\x1c\n\x14is_fps_limit_enabled\x18\x10 \x01(\x08\x12\x1c\n\x14is_tdp_limit_enabled\x18\x11 \x01(\x08\x12/\n\'is_show_perf_overlay_over_steam_enabled\x18\x12 \x01(\x08\x12#\n\x1bis_low_latency_mode_enabled\x18\x13 \x01(\x08\x12!\n\x19\x64isplay_refresh_manual_hz\x18\x14 \x01(\x05\x12$\n\x1cis_game_perf_profile_enabled\x18\x15 \x01(\x08\"\xa0\x01\n\x13\x43MsgSystemPerfState\x12%\n\x06limits\x18\x01 \x01(\x0b\x32\x15.CMsgSystemPerfLimits\x12)\n\x08settings\x18\x02 \x01(\x0b\x32\x17.CMsgSystemPerfSettings\x12\x17\n\x0f\x63urrent_game_id\x18\x03 \x01(\x04\x12\x1e\n\x16\x61\x63tive_profile_game_id\x18\x04 \x01(\x04\"\xa4\x01\n\x1c\x43MsgSystemPerfUpdateSettings\x12\x0e\n\x06gameid\x18\x01 \x01(\x04\x12\x1b\n\x13skip_storage_update\x18\x04 \x01(\x08\x12\x1a\n\x10reset_to_default\x18\x02 \x01(\x08H\x00\x12\x31\n\x0esettings_delta\x18\x03 \x01(\x0b\x32\x17.CMsgSystemPerfSettingsH\x00\x42\x08\n\x06update\"l\n CMsgSystemPerfLegacySettingEntry\x12\x17\n\x0fprofile_game_id\x18\x01 \x01(\x04\x12/\n\x08settings\x18\x02 \x01(\x0b\x32\x1d.CMsgSystemPerfSettingsPerApp\"\x8a\x01\n\x1c\x43MsgSystemPerfLegacySettings\x12-\n\x06global\x18\x01 \x01(\x0b\x32\x1d.CMsgSystemPerfSettingsGlobal\x12;\n\x10per_app_settings\x18\x02 \x03(\x0b\x32!.CMsgSystemPerfLegacySettingEntry\"\xfa\x01\n\x19\x43MsgSystemDockUpdateState\x12\x36\n\x05state\x18\x01 \x01(\x0e\x32\x0e.EUpdaterState:\x17k_EUpdaterState_Invalid\x12\x1a\n\x12rtime_last_checked\x18\x02 \x01(\x07\x12\x17\n\x0fversion_current\x18\x03 \x01(\t\x12\x19\n\x11version_available\x18\x04 \x01(\t\x12\x16\n\x0estage_progress\x18\x05 \x01(\x02\x12\"\n\x1artime_estimated_completion\x18\x06 \x01(\x07\x12\x19\n\x11old_fw_workaround\x18\x07 \x01(\x05\"G\n\x13\x43MsgSystemDockState\x12\x30\n\x0cupdate_state\x18\x01 \x01(\x0b\x32\x1a.CMsgSystemDockUpdateState\"2\n\x1c\x43MsgSystemDockUpdateFirmware\x12\x12\n\ncheck_only\x18\x01 \x01(\x08\"\xc5\x01\n\x15\x43MsgSystemAudioVolume\x12\x34\n\x07\x65ntries\x18\x01 \x03(\x0b\x32#.CMsgSystemAudioVolume.ChannelEntry\x12\x10\n\x08is_muted\x18\x02 \x01(\x08\x1a\x64\n\x0c\x43hannelEntry\x12\x44\n\x08\x65\x63hannel\x18\x01 \x01(\x0e\x32\x14.ESystemAudioChannel:\x1ck_SystemAudioChannel_Invalid\x12\x0e\n\x06volume\x18\x02 \x01(\x02\"E\n\x1c\x43MsgSystemAudioManagerObject\x12\n\n\x02id\x18\x01 \x01(\r\x12\x19\n\x11rtime_last_update\x18\x02 \x01(\x07\"\x89\x01\n\x1c\x43MsgSystemAudioManagerDevice\x12+\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1d.CMsgSystemAudioManagerObject\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04nick\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0b\n\x03\x61pi\x18\x05 \x01(\t\"\x81\x02\n\x1a\x43MsgSystemAudioManagerNode\x12+\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1d.CMsgSystemAudioManagerObject\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04nick\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12J\n\nedirection\x18\x06 \x01(\x0e\x32\x16.ESystemAudioDirection:\x1ek_SystemAudioDirection_Invalid\x12&\n\x06volume\x18\x07 \x01(\x0b\x32\x16.CMsgSystemAudioVolume\"\xe2\x02\n\x1a\x43MsgSystemAudioManagerPort\x12+\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1d.CMsgSystemAudioManagerObject\x12\x0f\n\x07node_id\x18\x03 \x01(\r\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\r\n\x05\x61lias\x18\x05 \x01(\t\x12\x43\n\x05\x65type\x18\x06 \x01(\x0e\x32\x15.ESystemAudioPortType:\x1dk_SystemAudioPortType_Invalid\x12R\n\nedirection\x18\x07 \x01(\x0e\x32\x1a.ESystemAudioPortDirection:\"k_SystemAudioPortDirection_Invalid\x12\x13\n\x0bis_physical\x18\x08 \x01(\x08\x12\x13\n\x0bis_terminal\x18\t \x01(\x08\x12\x12\n\nis_control\x18\n \x01(\x08\x12\x12\n\nis_monitor\x18\x0b \x01(\x08\"\xa7\x01\n\x1a\x43MsgSystemAudioManagerLink\x12+\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1d.CMsgSystemAudioManagerObject\x12\x16\n\x0eoutput_node_id\x18\x02 \x01(\r\x12\x16\n\x0eoutput_port_id\x18\x03 \x01(\r\x12\x15\n\rinput_node_id\x18\x04 \x01(\r\x12\x15\n\rinput_port_id\x18\x05 \x01(\r\"\xd3\x01\n\x1d\x43MsgSystemAudioManagerStateHW\x12.\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32\x1d.CMsgSystemAudioManagerDevice\x12*\n\x05nodes\x18\x02 \x03(\x0b\x32\x1b.CMsgSystemAudioManagerNode\x12*\n\x05ports\x18\x03 \x03(\x0b\x32\x1b.CMsgSystemAudioManagerPort\x12*\n\x05links\x18\x04 \x03(\x0b\x32\x1b.CMsgSystemAudioManagerLink\"p\n\x1b\x43MsgSystemAudioManagerState\x12\x14\n\x0crtime_filter\x18\x01 \x01(\x07\x12\x0f\n\x07\x63ounter\x18\x02 \x01(\x05\x12*\n\x02hw\x18\x03 \x01(\x0b\x32\x1e.CMsgSystemAudioManagerStateHW\"8\n%CMsgSystemAudioManagerUpdateSomething\x12\x0f\n\x07\x63ounter\x18\x01 \x01(\x05\"V\n\x15\x43MsgSystemDisplayMode\x12\n\n\x02id\x18\x01 \x01(\x05\x12\r\n\x05width\x18\x02 \x01(\x05\x12\x0e\n\x06height\x18\x03 \x01(\x05\x12\x12\n\nrefresh_hz\x18\x04 \x01(\x05\"\xc0\x03\n\x11\x43MsgSystemDisplay\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\nis_primary\x18\x04 \x01(\x08\x12\x12\n\nis_enabled\x18\x05 \x01(\x08\x12\x13\n\x0bis_internal\x18\x06 \x01(\x08\x12\x19\n\x11has_mode_override\x18\x07 \x01(\x08\x12\x10\n\x08width_mm\x18\x08 \x01(\x05\x12\x11\n\theight_mm\x18\t \x01(\x05\x12\x17\n\x0f\x63urrent_mode_id\x18\n \x01(\x05\x12%\n\x05modes\x18\x0b \x03(\x0b\x32\x16.CMsgSystemDisplayMode\x12\x18\n\x10refresh_rate_min\x18\x0c \x01(\x05\x12\x18\n\x10refresh_rate_max\x18\r \x01(\x05\x12\x16\n\x0eis_vrr_capable\x18\x0e \x01(\x08\x12\x1c\n\x14is_vrr_output_active\x18\x0f \x01(\x08\x12\x16\n\x0eis_hdr_capable\x18\x10 \x01(\x08\x12\x1c\n\x14is_hdr_output_active\x18\x11 \x01(\x08\x12\x1f\n\x17supported_refresh_rates\x18\x12 \x03(\x05\"\xd3\x01\n\x1d\x43MsgSystemDisplayManagerState\x12$\n\x08\x64isplays\x18\x01 \x03(\x0b\x32\x12.CMsgSystemDisplay\x12#\n\x1bis_mode_switching_supported\x18\x02 \x01(\x08\x12g\n\x12\x63ompatibility_mode\x18\x03 \x01(\x0e\x32 .ESystemDisplayCompatibilityMode:)k_ESystemDisplayCompatibilityMode_Invalid\"F\n\x1f\x43MsgSystemDisplayManagerSetMode\x12\x12\n\ndisplay_id\x18\x01 \x01(\x05\x12\x0f\n\x07mode_id\x18\x02 \x01(\x05\"\xa0\x0b\n\x19\x43MsgSystemManagerSettings\x12*\n\"idle_backlight_dim_battery_seconds\x18\x01 \x01(\x02\x12%\n\x1didle_backlight_dim_ac_seconds\x18\x02 \x01(\x02\x12$\n\x1cidle_suspend_battery_seconds\x18\x03 \x01(\x02\x12\x1f\n\x17idle_suspend_ac_seconds\x18\x04 \x01(\x02\x12\x1e\n\x16idle_suspend_supressed\x18\x05 \x01(\x08\x12(\n is_adaptive_brightness_available\x18\x06 \x01(\x08\x12+\n#display_adaptive_brightness_enabled\x18\x07 \x01(\x08\x12!\n\x19\x64isplay_nightmode_enabled\x18\n \x01(\x08\x12&\n\x1e\x64isplay_nightmode_tintstrength\x18\x0b \x01(\x02\x12 \n\x18\x64isplay_nightmode_maxhue\x18\x0c \x01(\x02\x12 \n\x18\x64isplay_nightmode_maxsat\x18\r \x01(\x02\x12\x1f\n\x17\x64isplay_nightmode_uiexp\x18\x0e \x01(\x02\x12\x1f\n\x17\x64isplay_nightmode_blend\x18\x0f \x01(\x02\x12\x1f\n\x17\x64isplay_nightmode_reset\x18\x10 \x01(\x08\x12*\n\"display_nightmode_schedule_enabled\x18\x11 \x01(\x08\x12,\n$display_nightmode_schedule_starttime\x18\x12 \x01(\x02\x12*\n\"display_nightmode_schedule_endtime\x18\x13 \x01(\x02\x12#\n\x1b\x64isplay_diagnostics_enabled\x18\x14 \x01(\x08\x12\x17\n\x0f\x61ls_lux_primary\x18\x15 \x01(\x02\x12\x16\n\x0e\x61ls_lux_median\x18\x16 \x01(\x02\x12\x1d\n\x15\x64isplay_backlight_raw\x18\x17 \x01(\x02\x12&\n\x1e\x64isplay_brightness_adaptivemin\x18\x18 \x01(\x02\x12&\n\x1e\x64isplay_brightness_adaptivemax\x18\x19 \x01(\x02\x12!\n\x19is_wifi_powersave_enabled\x18\x1a \x01(\x08\x12 \n\x18is_fan_control_available\x18\x1b \x01(\x08\x12P\n\x10\x66\x61n_control_mode\x18\x1c \x01(\x0e\x32\x16.ESystemFanControlMode:\x1ek_SystemFanControlMode_Invalid\x12\'\n\x1fis_display_brightness_available\x18\x1d \x01(\x08\x12,\n$is_display_colormanagement_available\x18\x1f \x01(\x08\x12\x1a\n\x12\x64isplay_colorgamut\x18  \x01(\x02\x12\x19\n\x11\x61ls_lux_alternate\x18! \x01(\x02\x12&\n\x1eis_display_colortemp_available\x18\" \x01(\x08\x12\x19\n\x11\x64isplay_colortemp\x18# \x01(\x02\x12!\n\x19\x64isplay_colortemp_default\x18$ \x01(\x02\x12!\n\x19\x64isplay_colortemp_enabled\x18% \x01(\x08\x12W\n\x1b\x64isplay_colorgamut_labelset\x18& \x01(\x0e\x32\x14.EColorGamutLabelSet:\x1ck_ColorGamutLabelSet_Default\x12.\n&display_brightness_overdrive_hdr_split\x18\' \x01(\x02\"b\n\x18\x43MsgSelectOSBranchParams\x12/\n\x06\x62ranch\x18\x01 \x01(\x0e\x32\n.EOSBranch:\x13k_EOSBranch_Unknown\x12\x15\n\rcustom_branch\x18\x02 \x01(\t\"p\n\x18\x43MsgSystemUpdateProgress\x12\x16\n\x0estage_progress\x18\x01 \x01(\x02\x12\x18\n\x10stage_size_bytes\x18\x02 \x01(\x03\x12\"\n\x1artime_estimated_completion\x18\x03 \x01(\x07\"\xd7\x01\n\x1b\x43MsgSystemUpdateCheckResult\x12\x33\n\x04type\x18\x01 \x01(\x0e\x32\r.EUpdaterType:\x16k_EUpdaterType_Invalid\x12\x12\n\x07\x65result\x18\x02 \x01(\r:\x01\x32\x12\x15\n\rrtime_checked\x18\x03 \x01(\x07\x12\x11\n\tavailable\x18\x04 \x01(\x08\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\x14\n\x0c\x61uto_message\x18\x06 \x01(\t\x12\x1e\n\x16system_restart_pending\x18\x07 \x01(\x08\"A\n\x1b\x43MsgSystemUpdateApplyParams\x12\"\n\x0b\x61pply_types\x18\x01 \x03(\x0e\x32\r.EUpdaterType\"\xb6\x01\n\x1b\x43MsgSystemUpdateApplyResult\x12\x33\n\x04type\x18\x01 \x01(\x0e\x32\r.EUpdaterType:\x16k_EUpdaterType_Invalid\x12\x12\n\x07\x65result\x18\x02 \x01(\r:\x01\x32\x12&\n\x17requires_client_restart\x18\x03 \x01(\x08:\x05\x66\x61lse\x12&\n\x17requires_system_restart\x18\x04 \x01(\x08:\x05\x66\x61lse\"\x91\x02\n\x15\x43MsgSystemUpdateState\x12\x36\n\x05state\x18\x01 \x01(\x0e\x32\x0e.EUpdaterState:\x17k_EUpdaterState_Invalid\x12+\n\x08progress\x18\x02 \x01(\x0b\x32\x19.CMsgSystemUpdateProgress\x12:\n\x14update_check_results\x18\x03 \x03(\x0b\x32\x1c.CMsgSystemUpdateCheckResult\x12:\n\x14update_apply_results\x18\x04 \x03(\x0b\x32\x1c.CMsgSystemUpdateApplyResult\x12\x1b\n\x13supports_os_updates\x18\x05 \x01(\x08\"&\n\x15\x43MsgAchievementChange\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"\\\n\x0c\x43MsgCellList\x12!\n\x05\x63\x65lls\x18\x01 \x03(\x0b\x32\x12.CMsgCellList.Cell\x1a)\n\x04\x43\x65ll\x12\x0f\n\x07\x63\x65ll_id\x18\x01 \x01(\r\x12\x10\n\x08loc_name\x18\x02 \x01(\t\"\xc6\x03\n\x10\x43MsgShortcutInfo\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0b\n\x03\x65xe\x18\x02 \x01(\t\x12\x11\n\tstart_dir\x18\x03 \x01(\t\x12\x0c\n\x04icon\x18\x04 \x01(\t\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\x0c\n\x04\x61rgs\x18\x06 \x01(\t\x12\x10\n\x08\x61pp_name\x18\x07 \x01(\t\x12\x16\n\x0eoverride_appid\x18\x08 \x01(\r\x12\x15\n\rflatpak_appid\x18\t \x01(\t\x12\x0c\n\x04tags\x18\n \x03(\t\x12\x18\n\x10remote_client_id\x18\x0b \x01(\x04\x12\x11\n\tis_hidden\x18\x0c \x01(\x08\x12\x14\n\x0cis_temporary\x18\r \x01(\x08\x12\x11\n\tis_openvr\x18\x0e \x01(\x08\x12\x1c\n\x14\x61llow_desktop_config\x18\x0f \x01(\x08\x12\x15\n\rallow_overlay\x18\x10 \x01(\x08\x12\x1b\n\x13rt_last_played_time\x18\x11 \x01(\r\x12\x1a\n\x12is_devkit_shortcut\x18\x12 \x01(\x08\x12\x15\n\rdevkit_gameid\x18\x13 \x01(\t\x12\x1f\n\x17remote_launch_available\x18\x14 \x01(\x08\x12\x0e\n\x06sortas\x18\x15 \x01(\t\"8\n\x11\x43MsgShortcutInfos\x12#\n\x08shorcuts\x18\x01 \x03(\x0b\x32\x11.CMsgShortcutInfo\"$\n\x12\x43MsgShortcutAppIds\x12\x0e\n\x06\x61ppids\x18\x01 \x03(\r\"\xaa\x01\n\x0f\x43MsgMonitorInfo\x12\x1d\n\x15selected_display_name\x18\x01 \x02(\t\x12.\n\x08monitors\x18\x02 \x03(\x0b\x32\x1c.CMsgMonitorInfo.MonitorInfo\x1aH\n\x0bMonitorInfo\x12\x1b\n\x13monitor_device_name\x18\x01 \x02(\t\x12\x1c\n\x14monitor_display_name\x18\x02 \x02(\t\"2\n\x1d\x43MsgGenerateSystemReportReply\x12\x11\n\treport_id\x18\x01 \x01(\t\"8\n\x16\x43MsgWebUITransportInfo\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\x10\n\x08\x61uth_key\x18\x02 \x01(\t\"2\n\x19\x43MsgWebUITransportFailure\x12\x15\n\rconnect_count\x18\x01 \x01(\r\"^\n\x1d\x43MsgClientShaderHitCacheEntry\x12\x0f\n\x07key_sha\x18\x01 \x01(\x0c\x12\x10\n\x08\x63ode_sha\x18\x02 \x01(\x0c\x12\x1a\n\x12time_last_reported\x18\x03 \x01(\x04\"K\n\x18\x43MsgClientShaderHitCache\x12/\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x1e.CMsgClientShaderHitCacheEntry*\x96\x02\n\x1c\x45\x43loudPendingRemoteOperation\x12&\n\"k_ECloudPendingRemoteOperationNone\x10\x00\x12\x32\n.k_ECloudPendingRemoteOperationAppSessionActive\x10\x01\x12\x32\n.k_ECloudPendingRemoteOperationUploadInProgress\x10\x02\x12/\n+k_ECloudPendingRemoteOperationUploadPending\x10\x03\x12\x35\n1k_ECloudPendingRemoteOperationAppSessionSuspended\x10\x04*\xca\x0c\n\x18\x45SteamDeckKeyboardLayout\x12%\n!k_ESteamDeckKeyboardLayout_QWERTY\x10\x00\x12(\n$k_ESteamDeckKeyboardLayout_Bulgarian\x10\x01\x12\x31\n-k_ESteamDeckKeyboardLayout_Chinese_Simplified\x10\x02\x12\x32\n.k_ESteamDeckKeyboardLayout_Chinese_Traditional\x10\x03\x12$\n k_ESteamDeckKeyboardLayout_Czech\x10\x04\x12%\n!k_ESteamDeckKeyboardLayout_Danish\x10\x05\x12&\n\"k_ESteamDeckKeyboardLayout_Finnish\x10\x06\x12%\n!k_ESteamDeckKeyboardLayout_French\x10\x07\x12%\n!k_ESteamDeckKeyboardLayout_German\x10\x08\x12$\n k_ESteamDeckKeyboardLayout_Greek\x10\t\x12(\n$k_ESteamDeckKeyboardLayout_Hungarian\x10\n\x12&\n\"k_ESteamDeckKeyboardLayout_Italian\x10\x0b\x12\'\n#k_ESteamDeckKeyboardLayout_Japanese\x10\x0c\x12%\n!k_ESteamDeckKeyboardLayout_Korean\x10\r\x12(\n$k_ESteamDeckKeyboardLayout_Norwegian\x10\x0e\x12%\n!k_ESteamDeckKeyboardLayout_Polish\x10\x0f\x12)\n%k_ESteamDeckKeyboardLayout_Portuguese\x10\x10\x12\'\n#k_ESteamDeckKeyboardLayout_Romanian\x10\x11\x12&\n\"k_ESteamDeckKeyboardLayout_Russian\x10\x12\x12&\n\"k_ESteamDeckKeyboardLayout_Spanish\x10\x13\x12&\n\"k_ESteamDeckKeyboardLayout_Swedish\x10\x14\x12#\n\x1fk_ESteamDeckKeyboardLayout_Thai\x10\x15\x12(\n$k_ESteamDeckKeyboardLayout_Turkish_F\x10\x16\x12(\n$k_ESteamDeckKeyboardLayout_Turkish_Q\x10\x17\x12(\n$k_ESteamDeckKeyboardLayout_Ukrainian\x10\x18\x12)\n%k_ESteamDeckKeyboardLayout_Vietnamese\x10\x19\x12\x33\n/k_ESteamDeckKeyboardLayout_QWERTY_International\x10\x1a\x12%\n!k_ESteamDeckKeyboardLayout_Dvorak\x10\x1b\x12&\n\"k_ESteamDeckKeyboardLayout_Colemak\x10\x1c\x12=\n9k_ESteamDeckKeyboardLayout_Bulgarian_Phonetic_Traditional\x10\x1d\x12\x31\n-k_ESteamDeckKeyboardLayout_Bulgarian_Phonetic\x10\x1e\x12;\n7k_ESteamDeckKeyboardLayout_Chinese_Traditional_Bopomofo\x10\x1f\x12:\n6k_ESteamDeckKeyboardLayout_Chinese_Traditional_Cangjie\x10 \x12,\n(k_ESteamDeckKeyboardLayout_Japanese_Kana\x10!\x12\x38\n4k_ESteamDeckKeyboardLayout_Chinese_Traditional_Quick\x10\"\x12)\n%k_ESteamDeckKeyboardLayout_Indonesian\x10#B\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_client_objects_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _ECLOUDPENDINGREMOTEOPERATION._serialized_start=15037
  _ECLOUDPENDINGREMOTEOPERATION._serialized_end=15315
  _ESTEAMDECKKEYBOARDLAYOUT._serialized_start=15318
  _ESTEAMDECKKEYBOARDLAYOUT._serialized_end=16928
  _STEAMMESSAGESCLIENTICLIENTFORCEDENUMDEPENDENCIES._serialized_start=52
  _STEAMMESSAGESCLIENTICLIENTFORCEDENUMDEPENDENCIES._serialized_end=383
  _CMSGNETWORKDEVICEIP4ADDRESS._serialized_start=385
  _CMSGNETWORKDEVICEIP4ADDRESS._serialized_end=446
  _CMSGNETWORKDEVICEIP4CONFIG._serialized_start=449
  _CMSGNETWORKDEVICEIP4CONFIG._serialized_end=640
  _CMSGNETWORKDEVICEIP6ADDRESS._serialized_start=642
  _CMSGNETWORKDEVICEIP6ADDRESS._serialized_end=683
  _CMSGNETWORKDEVICEIP6CONFIG._serialized_start=686
  _CMSGNETWORKDEVICEIP6CONFIG._serialized_end=877
  _CMSGNETWORKDEVICESDATA._serialized_start=880
  _CMSGNETWORKDEVICESDATA._serialized_end=1671
  _CMSGNETWORKDEVICESDATA_DEVICE._serialized_start=1015
  _CMSGNETWORKDEVICESDATA_DEVICE._serialized_end=1671
  _CMSGNETWORKDEVICESDATA_DEVICE_WIRED._serialized_start=1313
  _CMSGNETWORKDEVICESDATA_DEVICE_WIRED._serialized_end=1396
  _CMSGNETWORKDEVICESDATA_DEVICE_WIRELESS._serialized_start=1399
  _CMSGNETWORKDEVICESDATA_DEVICE_WIRELESS._serialized_end=1671
  _CMSGNETWORKDEVICESDATA_DEVICE_WIRELESS_AP._serialized_start=1498
  _CMSGNETWORKDEVICESDATA_DEVICE_WIRELESS_AP._serialized_end=1671
  _CMSGNETWORKDEVICECONNECT._serialized_start=1674
  _CMSGNETWORKDEVICECONNECT._serialized_end=2111
  _CMSGNETWORKDEVICECONNECT_KNOWNAP._serialized_start=1980
  _CMSGNETWORKDEVICECONNECT_KNOWNAP._serialized_end=2004
  _CMSGNETWORKDEVICECONNECT_CUSTOMAP._serialized_start=2006
  _CMSGNETWORKDEVICECONNECT_CUSTOMAP._serialized_end=2049
  _CMSGNETWORKDEVICECONNECT_CREDENTIALS._serialized_start=2051
  _CMSGNETWORKDEVICECONNECT_CREDENTIALS._serialized_end=2100
  _CMSGSTORAGEDEVICESDATA._serialized_start=2114
  _CMSGSTORAGEDEVICESDATA._serialized_end=2913
  _CMSGSTORAGEDEVICESDATA_DRIVE._serialized_start=2330
  _CMSGSTORAGEDEVICESDATA_DRIVE._serialized_end=2520
  _CMSGSTORAGEDEVICESDATA_BLOCKDEVICE._serialized_start=2523
  _CMSGSTORAGEDEVICESDATA_BLOCKDEVICE._serialized_end=2913
  _CCLOUD_PENDINGREMOTEOPERATION._serialized_start=2916
  _CCLOUD_PENDINGREMOTEOPERATION._serialized_end=3139
  _CMSGCLOUDPENDINGREMOTEOPERATIONS._serialized_start=3141
  _CMSGCLOUDPENDINGREMOTEOPERATIONS._serialized_end=3227
  _CMSGBLUETOOTHDEVICESDATA._serialized_start=3230
  _CMSGBLUETOOTHDEVICESDATA._serialized_end=3837
  _CMSGBLUETOOTHDEVICESDATA_ADAPTER._serialized_start=3414
  _CMSGBLUETOOTHDEVICESDATA_ADAPTER._serialized_end=3509
  _CMSGBLUETOOTHDEVICESDATA_DEVICE._serialized_start=3512
  _CMSGBLUETOOTHDEVICESDATA_DEVICE._serialized_end=3796
  _CMSGBLUETOOTHDEVICESDATA_MANAGER._serialized_start=3798
  _CMSGBLUETOOTHDEVICESDATA_MANAGER._serialized_end=3837
  _CMSGSYSTEMPERFDIAGNOSTICENTRY._serialized_start=3839
  _CMSGSYSTEMPERFDIAGNOSTICENTRY._serialized_end=3899
  _CMSGSYSTEMPERFNETWORKINTERFACE._serialized_start=3902
  _CMSGSYSTEMPERFNETWORKINTERFACE._serialized_end=4067
  _CMSGSYSTEMPERFDIAGNOSTICINFO._serialized_start=4070
  _CMSGSYSTEMPERFDIAGNOSTICINFO._serialized_end=4226
  _CMSGSYSTEMPERFLIMITS._serialized_start=4229
  _CMSGSYSTEMPERFLIMITS._serialized_end=5172
  _CMSGSYSTEMPERFSETTINGSGLOBAL._serialized_start=5175
  _CMSGSYSTEMPERFSETTINGSGLOBAL._serialized_end=5990
  _CMSGSYSTEMPERFSETTINGSPERAPP._serialized_start=5993
  _CMSGSYSTEMPERFSETTINGSPERAPP._serialized_end=6908
  _CMSGSYSTEMPERFSETTINGS._serialized_start=6910
  _CMSGSYSTEMPERFSETTINGS._serialized_end=7029
  _CMSGSYSTEMPERFSETTINGSV1._serialized_start=7032
  _CMSGSYSTEMPERFSETTINGSV1._serialized_end=8068
  _CMSGSYSTEMPERFSTATE._serialized_start=8071
  _CMSGSYSTEMPERFSTATE._serialized_end=8231
  _CMSGSYSTEMPERFUPDATESETTINGS._serialized_start=8234
  _CMSGSYSTEMPERFUPDATESETTINGS._serialized_end=8398
  _CMSGSYSTEMPERFLEGACYSETTINGENTRY._serialized_start=8400
  _CMSGSYSTEMPERFLEGACYSETTINGENTRY._serialized_end=8508
  _CMSGSYSTEMPERFLEGACYSETTINGS._serialized_start=8511
  _CMSGSYSTEMPERFLEGACYSETTINGS._serialized_end=8649
  _CMSGSYSTEMDOCKUPDATESTATE._serialized_start=8652
  _CMSGSYSTEMDOCKUPDATESTATE._serialized_end=8902
  _CMSGSYSTEMDOCKSTATE._serialized_start=8904
  _CMSGSYSTEMDOCKSTATE._serialized_end=8975
  _CMSGSYSTEMDOCKUPDATEFIRMWARE._serialized_start=8977
  _CMSGSYSTEMDOCKUPDATEFIRMWARE._serialized_end=9027
  _CMSGSYSTEMAUDIOVOLUME._serialized_start=9030
  _CMSGSYSTEMAUDIOVOLUME._serialized_end=9227
  _CMSGSYSTEMAUDIOVOLUME_CHANNELENTRY._serialized_start=9127
  _CMSGSYSTEMAUDIOVOLUME_CHANNELENTRY._serialized_end=9227
  _CMSGSYSTEMAUDIOMANAGEROBJECT._serialized_start=9229
  _CMSGSYSTEMAUDIOMANAGEROBJECT._serialized_end=9298
  _CMSGSYSTEMAUDIOMANAGERDEVICE._serialized_start=9301
  _CMSGSYSTEMAUDIOMANAGERDEVICE._serialized_end=9438
  _CMSGSYSTEMAUDIOMANAGERNODE._serialized_start=9441
  _CMSGSYSTEMAUDIOMANAGERNODE._serialized_end=9698
  _CMSGSYSTEMAUDIOMANAGERPORT._serialized_start=9701
  _CMSGSYSTEMAUDIOMANAGERPORT._serialized_end=10055
  _CMSGSYSTEMAUDIOMANAGERLINK._serialized_start=10058
  _CMSGSYSTEMAUDIOMANAGERLINK._serialized_end=10225
  _CMSGSYSTEMAUDIOMANAGERSTATEHW._serialized_start=10228
  _CMSGSYSTEMAUDIOMANAGERSTATEHW._serialized_end=10439
  _CMSGSYSTEMAUDIOMANAGERSTATE._serialized_start=10441
  _CMSGSYSTEMAUDIOMANAGERSTATE._serialized_end=10553
  _CMSGSYSTEMAUDIOMANAGERUPDATESOMETHING._serialized_start=10555
  _CMSGSYSTEMAUDIOMANAGERUPDATESOMETHING._serialized_end=10611
  _CMSGSYSTEMDISPLAYMODE._serialized_start=10613
  _CMSGSYSTEMDISPLAYMODE._serialized_end=10699
  _CMSGSYSTEMDISPLAY._serialized_start=10702
  _CMSGSYSTEMDISPLAY._serialized_end=11150
  _CMSGSYSTEMDISPLAYMANAGERSTATE._serialized_start=11153
  _CMSGSYSTEMDISPLAYMANAGERSTATE._serialized_end=11364
  _CMSGSYSTEMDISPLAYMANAGERSETMODE._serialized_start=11366
  _CMSGSYSTEMDISPLAYMANAGERSETMODE._serialized_end=11436
  _CMSGSYSTEMMANAGERSETTINGS._serialized_start=11439
  _CMSGSYSTEMMANAGERSETTINGS._serialized_end=12879
  _CMSGSELECTOSBRANCHPARAMS._serialized_start=12881
  _CMSGSELECTOSBRANCHPARAMS._serialized_end=12979
  _CMSGSYSTEMUPDATEPROGRESS._serialized_start=12981
  _CMSGSYSTEMUPDATEPROGRESS._serialized_end=13093
  _CMSGSYSTEMUPDATECHECKRESULT._serialized_start=13096
  _CMSGSYSTEMUPDATECHECKRESULT._serialized_end=13311
  _CMSGSYSTEMUPDATEAPPLYPARAMS._serialized_start=13313
  _CMSGSYSTEMUPDATEAPPLYPARAMS._serialized_end=13378
  _CMSGSYSTEMUPDATEAPPLYRESULT._serialized_start=13381
  _CMSGSYSTEMUPDATEAPPLYRESULT._serialized_end=13563
  _CMSGSYSTEMUPDATESTATE._serialized_start=13566
  _CMSGSYSTEMUPDATESTATE._serialized_end=13839
  _CMSGACHIEVEMENTCHANGE._serialized_start=13841
  _CMSGACHIEVEMENTCHANGE._serialized_end=13879
  _CMSGCELLLIST._serialized_start=13881
  _CMSGCELLLIST._serialized_end=13973
  _CMSGCELLLIST_CELL._serialized_start=13932
  _CMSGCELLLIST_CELL._serialized_end=13973
  _CMSGSHORTCUTINFO._serialized_start=13976
  _CMSGSHORTCUTINFO._serialized_end=14430
  _CMSGSHORTCUTINFOS._serialized_start=14432
  _CMSGSHORTCUTINFOS._serialized_end=14488
  _CMSGSHORTCUTAPPIDS._serialized_start=14490
  _CMSGSHORTCUTAPPIDS._serialized_end=14526
  _CMSGMONITORINFO._serialized_start=14529
  _CMSGMONITORINFO._serialized_end=14699
  _CMSGMONITORINFO_MONITORINFO._serialized_start=14627
  _CMSGMONITORINFO_MONITORINFO._serialized_end=14699
  _CMSGGENERATESYSTEMREPORTREPLY._serialized_start=14701
  _CMSGGENERATESYSTEMREPORTREPLY._serialized_end=14751
  _CMSGWEBUITRANSPORTINFO._serialized_start=14753
  _CMSGWEBUITRANSPORTINFO._serialized_end=14809
  _CMSGWEBUITRANSPORTFAILURE._serialized_start=14811
  _CMSGWEBUITRANSPORTFAILURE._serialized_end=14861
  _CMSGCLIENTSHADERHITCACHEENTRY._serialized_start=14863
  _CMSGCLIENTSHADERHITCACHEENTRY._serialized_end=14957
  _CMSGCLIENTSHADERHITCACHE._serialized_start=14959
  _CMSGCLIENTSHADERHITCACHE._serialized_end=15034
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_auth.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.enums_pb2 as enums__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18steammessages_auth.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\x1a\x0b\x65nums.proto\"G\n/CAuthentication_GetPasswordRSAPublicKey_Request\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x01 \x01(\t\"s\n0CAuthentication_GetPasswordRSAPublicKey_Response\x12\x15\n\rpublickey_mod\x18\x01 \x01(\t\x12\x15\n\rpublickey_exp\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x04\"\xa9\x02\n\x1d\x43\x41uthentication_DeviceDetails\x12\x1c\n\x14\x64\x65vice_friendly_name\x18\x01 \x01(\t\x12P\n\rplatform_type\x18\x02 \x01(\x0e\x32\x17.EAuthTokenPlatformType: k_EAuthTokenPlatformType_Unknown\x12\x0f\n\x07os_type\x18\x03 \x01(\x05\x12\x1a\n\x12gaming_device_type\x18\x04 \x01(\r\x12\x14\n\x0c\x63lient_count\x18\x05 \x01(\r\x12\x12\n\nmachine_id\x18\x06 \x01(\x0c\x12\x41\n\x08\x61pp_type\x18\x07 \x01(\x0e\x32\x12.EAuthTokenAppType:\x1bk_EAuthTokenAppType_Unknown\"\xf4\x01\n-CAuthentication_BeginAuthSessionViaQR_Request\x12\x1c\n\x14\x64\x65vice_friendly_name\x18\x01 \x01(\t\x12P\n\rplatform_type\x18\x02 \x01(\x0e\x32\x17.EAuthTokenPlatformType: k_EAuthTokenPlatformType_Unknown\x12\x36\n\x0e\x64\x65vice_details\x18\x03 \x01(\x0b\x32\x1e.CAuthentication_DeviceDetails\x12\x1b\n\nwebsite_id\x18\x04 \x01(\t:\x07Unknown\"\x95\x01\n#CAuthentication_AllowedConfirmation\x12R\n\x11\x63onfirmation_type\x18\x01 \x01(\x0e\x32\x16.EAuthSessionGuardType:\x1fk_EAuthSessionGuardType_Unknown\x12\x1a\n\x12\x61ssociated_message\x18\x02 \x01(\t\"\xd6\x01\n.CAuthentication_BeginAuthSessionViaQR_Response\x12\x11\n\tclient_id\x18\x01 \x01(\x04\x12\x15\n\rchallenge_url\x18\x02 \x01(\t\x12\x12\n\nrequest_id\x18\x03 \x01(\x0c\x12\x10\n\x08interval\x18\x04 \x01(\x02\x12\x43\n\x15\x61llowed_confirmations\x18\x05 \x03(\x0b\x32$.CAuthentication_AllowedConfirmation\x12\x0f\n\x07version\x18\x06 \x01(\x05\"\xee\x03\n6CAuthentication_BeginAuthSessionViaCredentials_Request\x12\x1c\n\x14\x64\x65vice_friendly_name\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x02 \x01(\t\x12\x1a\n\x12\x65ncrypted_password\x18\x03 \x01(\t\x12\x1c\n\x14\x65ncryption_timestamp\x18\x04 \x01(\x04\x12\x16\n\x0eremember_login\x18\x05 \x01(\x08\x12P\n\rplatform_type\x18\x06 \x01(\x0e\x32\x17.EAuthTokenPlatformType: k_EAuthTokenPlatformType_Unknown\x12K\n\x0bpersistence\x18\x07 \x01(\x0e\x32\x14.ESessionPersistence: k_ESessionPersistence_Persistent\x12\x1b\n\nwebsite_id\x18\x08 \x01(\t:\x07Unknown\x12\x36\n\x0e\x64\x65vice_details\x18\t \x01(\x0b\x32\x1e.CAuthentication_DeviceDetails\x12\x12\n\nguard_data\x18\n \x01(\t\x12\x10\n\x08language\x18\x0b \x01(\r\x12\x14\n\tqos_level\x18\x0c \x01(\x05:\x01\x32\"\x9b\x02\n7CAuthentication_BeginAuthSessionViaCredentials_Response\x12\x11\n\tclient_id\x18\x01 \x01(\x04\x12\x12\n\nrequest_id\x18\x02 \x01(\x0c\x12\x10\n\x08interval\x18\x03 \x01(\x02\x12\x43\n\x15\x61llowed_confirmations\x18\x04 \x03(\x0b\x32$.CAuthentication_AllowedConfirmation\x12\x0f\n\x07steamid\x18\x05 \x01(\x04\x12\x12\n\nweak_token\x18\x06 \x01(\t\x12\x1d\n\x15\x61greement_session_url\x18\x07 \x01(\t\x12\x1e\n\x16\x65xtended_error_message\x18\x08 \x01(\t\"o\n-CAuthentication_PollAuthSessionStatus_Request\x12\x11\n\tclient_id\x18\x01 \x01(\x04\x12\x12\n\nrequest_id\x18\x02 \x01(\x0c\x12\x17\n\x0ftoken_to_revoke\x18\x03 \x01(\x06\"\xfc\x01\n.CAuthentication_PollAuthSessionStatus_Response\x12\x15\n\rnew_client_id\x18\x01 \x01(\x04\x12\x19\n\x11new_challenge_url\x18\x02 \x01(\t\x12\x15\n\rrefresh_token\x18\x03 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x04 \x01(\t\x12\x1e\n\x16had_remote_interaction\x18\x05 \x01(\x08\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x06 \x01(\t\x12\x16\n\x0enew_guard_data\x18\x07 \x01(\t\x12\x1d\n\x15\x61greement_session_url\x18\x08 \x01(\t\"?\n*CAuthentication_GetAuthSessionInfo_Request\x12\x11\n\tclient_id\x18\x01 \x01(\x04\"\xc0\x04\n+CAuthentication_GetAuthSessionInfo_Response\x12\n\n\x02ip\x18\x01 \x01(\t\x12\x0e\n\x06geoloc\x18\x02 \x01(\t\x12\x0c\n\x04\x63ity\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x05 \x01(\t\x12P\n\rplatform_type\x18\x06 \x01(\x0e\x32\x17.EAuthTokenPlatformType: k_EAuthTokenPlatformType_Unknown\x12\x1c\n\x14\x64\x65vice_friendly_name\x18\x07 \x01(\t\x12\x0f\n\x07version\x18\x08 \x01(\x05\x12Z\n\rlogin_history\x18\t \x01(\x0e\x32\x1c.EAuthSessionSecurityHistory:%k_EAuthSessionSecurityHistory_Invalid\x12#\n\x1brequestor_location_mismatch\x18\n \x01(\x08\x12\x18\n\x10high_usage_login\x18\x0b \x01(\x08\x12R\n\x15requested_persistence\x18\x0c \x01(\x0e\x32\x14.ESessionPersistence:\x1dk_ESessionPersistence_Invalid\x12\x14\n\x0c\x64\x65vice_trust\x18\r \x01(\x05\x12\x41\n\x08\x61pp_type\x18\x0e \x01(\x0e\x32\x12.EAuthTokenAppType:\x1bk_EAuthTokenAppType_Unknown\"U\n.CAuthentication_GetAuthSessionRiskInfo_Request\x12\x11\n\tclient_id\x18\x01 \x01(\x04\x12\x10\n\x08language\x18\x02 \x01(\r\"\xd3\x01\n/CAuthentication_GetAuthSessionRiskInfo_Response\x12\x1a\n\x12location_confirmer\x18\x01 \x01(\t\x12\x1a\n\x12location_requestor\x18\x02 \x01(\t\x12\x16\n\x0elocation_other\x18\x03 \x01(\t\x12P\n\rplatform_type\x18\x04 \x01(\x0e\x32\x17.EAuthTokenPlatformType: k_EAuthTokenPlatformType_Unknown\"\x98\x02\n2CAuthentication_NotifyRiskQuizResults_Notification\x12\x11\n\tclient_id\x18\x01 \x01(\x04\x12T\n\x07results\x18\x02 \x01(\x0b\x32\x43.CAuthentication_NotifyRiskQuizResults_Notification.RiskQuizResults\x12\x17\n\x0fselected_action\x18\x03 \x01(\t\x12\x19\n\x11\x64id_confirm_login\x18\x04 \x01(\x08\x1a\x45\n\x0fRiskQuizResults\x12\x10\n\x08platform\x18\x01 \x01(\x08\x12\x10\n\x08location\x18\x02 \x01(\x08\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\x08\"\xee\x01\n?CAuthentication_UpdateAuthSessionWithMobileConfirmation_Request\x12\x0f\n\x07version\x18\x01 \x01(\x05\x12\x11\n\tclient_id\x18\x02 \x01(\x04\x12\x0f\n\x07steamid\x18\x03 \x01(\x06\x12\x11\n\tsignature\x18\x04 \x01(\x0c\x12\x16\n\x07\x63onfirm\x18\x05 \x01(\x08:\x05\x66\x61lse\x12K\n\x0bpersistence\x18\x06 \x01(\x0e\x32\x14.ESessionPersistence: k_ESessionPersistence_Persistent\"B\n@CAuthentication_UpdateAuthSessionWithMobileConfirmation_Response\"\xbb\x01\n;CAuthentication_UpdateAuthSessionWithSteamGuardCode_Request\x12\x11\n\tclient_id\x18\x01 \x01(\x04\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12J\n\tcode_type\x18\x04 \x01(\x0e\x32\x16.EAuthSessionGuardType:\x1fk_EAuthSessionGuardType_Unknown\"]\n<CAuthentication_UpdateAuthSessionWithSteamGuardCode_Response\x12\x1d\n\x15\x61greement_session_url\x18\x07 \x01(\t\"\xa0\x01\n2CAuthentication_AccessToken_GenerateForApp_Request\x12\x15\n\rrefresh_token\x18\x01 \x01(\t\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x12\x42\n\x0crenewal_type\x18\x03 \x01(\x0e\x32\x12.ETokenRenewalType:\x18k_ETokenRenewalType_None\"b\n3CAuthentication_AccessToken_GenerateForApp_Response\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\"P\n.CAuthentication_RefreshToken_Enumerate_Request\x12\x1e\n\x0finclude_revoked\x18\x01 \x01(\x08:\x05\x66\x61lse\"\x8a\x07\n/CAuthentication_RefreshToken_Enumerate_Response\x12`\n\x0erefresh_tokens\x18\x01 \x03(\x0b\x32H.CAuthentication_RefreshToken_Enumerate_Response.RefreshTokenDescription\x12\x18\n\x10requesting_token\x18\x02 \x01(\x06\x1ay\n\x0fTokenUsageEvent\x12\x0c\n\x04time\x18\x01 \x01(\r\x12\x1a\n\x02ip\x18\x02 \x01(\x0b\x32\x0e.CMsgIPAddress\x12\x0e\n\x06locale\x18\x03 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x04 \x01(\t\x12\r\n\x05state\x18\x05 \x01(\t\x12\x0c\n\x04\x63ity\x18\x06 \x01(\t\x1a\xdf\x04\n\x17RefreshTokenDescription\x12\x10\n\x08token_id\x18\x01 \x01(\x06\x12\x19\n\x11token_description\x18\x02 \x01(\t\x12\x14\n\x0ctime_updated\x18\x03 \x01(\r\x12P\n\rplatform_type\x18\x04 \x01(\x0e\x32\x17.EAuthTokenPlatformType: k_EAuthTokenPlatformType_Unknown\x12\x11\n\tlogged_in\x18\x05 \x01(\x08\x12\x13\n\x0bos_platform\x18\x06 \x01(\r\x12\x11\n\tauth_type\x18\x07 \x01(\r\x12\x1a\n\x12gaming_device_type\x18\x08 \x01(\r\x12T\n\nfirst_seen\x18\t \x01(\x0b\x32@.CAuthentication_RefreshToken_Enumerate_Response.TokenUsageEvent\x12S\n\tlast_seen\x18\n \x01(\x0b\x32@.CAuthentication_RefreshToken_Enumerate_Response.TokenUsageEvent\x12\x0f\n\x07os_type\x18\x0b \x01(\x05\x12P\n\x13\x61uthentication_type\x18\x0c \x01(\x0e\x32\x14.EAuthenticationType:\x1dk_EAuthenticationType_Unknown\x12J\n\x15\x65\x66\x66\x65\x63tive_token_state\x18\r \x01(\x0e\x32\x10.EAuthTokenState:\x19k_EAuthTokenState_Invalid\"3\n1CAuthentication_GetAuthSessionsForAccount_Request\"H\n2CAuthentication_GetAuthSessionsForAccount_Response\x12\x12\n\nclient_ids\x18\x01 \x03(\x04\"a\n,CAuthentication_MigrateMobileSession_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\r\n\x05token\x18\x02 \x01(\t\x12\x11\n\tsignature\x18\x03 \x01(\t\"\\\n-CAuthentication_MigrateMobileSession_Response\x12\x15\n\rrefresh_token\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x02 \x01(\t\"\x82\x01\n$CAuthentication_Token_Revoke_Request\x12\r\n\x05token\x18\x01 \x01(\t\x12K\n\rrevoke_action\x18\x02 \x01(\x0e\x32\x17.EAuthTokenRevokeAction:\x1bk_EAuthTokenRevokePermanent\"\'\n%CAuthentication_Token_Revoke_Response\"\xb0\x01\n+CAuthentication_RefreshToken_Revoke_Request\x12\x10\n\x08token_id\x18\x01 \x01(\x06\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x12K\n\rrevoke_action\x18\x03 \x01(\x0e\x32\x17.EAuthTokenRevokeAction:\x1bk_EAuthTokenRevokePermanent\x12\x11\n\tsignature\x18\x04 \x01(\x0c\".\n,CAuthentication_RefreshToken_Revoke_Response\"m\n:CAuthenticationSupport_QueryRefreshTokensByAccount_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x1e\n\x16include_revoked_tokens\x18\x02 \x01(\x08\"\xda\x04\n\x1f\x43SupportRefreshTokenDescription\x12\x10\n\x08token_id\x18\x01 \x01(\x06\x12\x19\n\x11token_description\x18\x02 \x01(\t\x12\x14\n\x0ctime_updated\x18\x03 \x01(\r\x12P\n\rplatform_type\x18\x04 \x01(\x0e\x32\x17.EAuthTokenPlatformType: k_EAuthTokenPlatformType_Unknown\x12@\n\x0btoken_state\x18\x05 \x01(\x0e\x32\x10.EAuthTokenState:\x19k_EAuthTokenState_Invalid\x12\x15\n\rowner_steamid\x18\x06 \x01(\x06\x12\x13\n\x0bos_platform\x18\x07 \x01(\r\x12\x0f\n\x07os_type\x18\x08 \x01(\x05\x12\x11\n\tauth_type\x18\t \x01(\r\x12\x1a\n\x12gaming_device_type\x18\n \x01(\r\x12\x44\n\nfirst_seen\x18\x0b \x01(\x0b\x32\x30.CSupportRefreshTokenDescription.TokenUsageEvent\x12\x43\n\tlast_seen\x18\x0c \x01(\x0b\x32\x30.CSupportRefreshTokenDescription.TokenUsageEvent\x1ai\n\x0fTokenUsageEvent\x12\x0c\n\x04time\x18\x01 \x01(\r\x12\x1a\n\x02ip\x18\x02 \x01(\x0b\x32\x0e.CMsgIPAddress\x12\x0f\n\x07\x63ountry\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12\x0c\n\x04\x63ity\x18\x05 \x01(\t\"\x91\x01\n;CAuthenticationSupport_QueryRefreshTokensByAccount_Response\x12\x38\n\x0erefresh_tokens\x18\x01 \x03(\x0b\x32 .CSupportRefreshTokenDescription\x12\x18\n\x10last_token_reset\x18\x02 \x01(\x05\"H\n4CAuthenticationSupport_QueryRefreshTokenByID_Request\x12\x10\n\x08token_id\x18\x01 \x01(\x06\"q\n5CAuthenticationSupport_QueryRefreshTokenByID_Response\x12\x38\n\x0erefresh_tokens\x18\x01 \x03(\x0b\x32 .CSupportRefreshTokenDescription\"O\n*CAuthenticationSupport_RevokeToken_Request\x12\x10\n\x08token_id\x18\x01 \x01(\x06\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\"-\n+CAuthenticationSupport_RevokeToken_Response\"B\n.CAuthenticationSupport_GetTokenHistory_Request\x12\x10\n\x08token_id\x18\x01 \x01(\x06\"d\n\x19\x43SupportRefreshTokenAudit\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\x05\x12\x0c\n\x04time\x18\x02 \x01(\r\x12\x1a\n\x02ip\x18\x03 \x01(\x0b\x32\x0e.CMsgIPAddress\x12\r\n\x05\x61\x63tor\x18\x04 \x01(\x06\"^\n/CAuthenticationSupport_GetTokenHistory_Response\x12+\n\x07history\x18\x01 \x03(\x0b\x32\x1a.CSupportRefreshTokenAudit\"X\n3CAuthenticationSupport_MarkTokenCompromised_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x10\n\x08token_id\x18\x02 \x01(\x06\"6\n4CAuthenticationSupport_MarkTokenCompromised_Response\"C\n CCloudGaming_CreateNonce_Request\x12\x10\n\x08platform\x18\x01 \x01(\t\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\"B\n!CCloudGaming_CreateNonce_Response\x12\r\n\x05nonce\x18\x01 \x01(\t\x12\x0e\n\x06\x65xpiry\x18\x02 \x01(\r\"M\n%CCloudGaming_GetTimeRemaining_Request\x12\x10\n\x08platform\x18\x01 \x01(\t\x12\x12\n\nappid_list\x18\x02 \x03(\r\"F\n\x1a\x43\x43loudGaming_TimeRemaining\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x19\n\x11minutes_remaining\x18\x02 \x01(\r\"V\n&CCloudGaming_GetTimeRemaining_Response\x12,\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x1b.CCloudGaming_TimeRemaining*\xb9\x01\n\x16\x45\x41uthTokenPlatformType\x12$\n k_EAuthTokenPlatformType_Unknown\x10\x00\x12(\n$k_EAuthTokenPlatformType_SteamClient\x10\x01\x12\'\n#k_EAuthTokenPlatformType_WebBrowser\x10\x02\x12&\n\"k_EAuthTokenPlatformType_MobileApp\x10\x03*\x85\x01\n\x11\x45\x41uthTokenAppType\x12\x1f\n\x1bk_EAuthTokenAppType_Unknown\x10\x00\x12\'\n#k_EAuthTokenAppType_Mobile_SteamApp\x10\x01\x12&\n\"k_EAuthTokenAppType_Mobile_ChatApp\x10\x02*\xe5\x02\n\x15\x45\x41uthSessionGuardType\x12#\n\x1fk_EAuthSessionGuardType_Unknown\x10\x00\x12 \n\x1ck_EAuthSessionGuardType_None\x10\x01\x12%\n!k_EAuthSessionGuardType_EmailCode\x10\x02\x12&\n\"k_EAuthSessionGuardType_DeviceCode\x10\x03\x12.\n*k_EAuthSessionGuardType_DeviceConfirmation\x10\x04\x12-\n)k_EAuthSessionGuardType_EmailConfirmation\x10\x05\x12(\n$k_EAuthSessionGuardType_MachineToken\x10\x06\x12-\n)k_EAuthSessionGuardType_LegacyMachineAuth\x10\x07*\xac\x01\n\x1b\x45\x41uthSessionSecurityHistory\x12)\n%k_EAuthSessionSecurityHistory_Invalid\x10\x00\x12\x30\n,k_EAuthSessionSecurityHistory_UsedPreviously\x10\x01\x12\x30\n,k_EAuthSessionSecurityHistory_NoPriorHistory\x10\x02*P\n\x11\x45TokenRenewalType\x12\x1c\n\x18k_ETokenRenewalType_None\x10\x00\x12\x1d\n\x19k_ETokenRenewalType_Allow\x10\x01*\xcd\x01\n\x13\x45\x41uthenticationType\x12!\n\x1dk_EAuthenticationType_Unknown\x10\x00\x12\"\n\x1ek_EAuthenticationType_Password\x10\x01\x12\x1c\n\x18k_EAuthenticationType_QR\x10\x02\x12)\n%k_EAuthenticationType_AccountCreation\x10\x03\x12&\n\"k_EAuthenticationType_GuestAccount\x10\x04*\x88\x02\n\x0f\x45\x41uthTokenState\x12\x1d\n\x19k_EAuthTokenState_Invalid\x10\x00\x12\x19\n\x15k_EAuthTokenState_New\x10\x01\x12\x1f\n\x1bk_EAuthTokenState_Confirmed\x10\x02\x12\x1c\n\x18k_EAuthTokenState_Issued\x10\x03\x12\x1c\n\x18k_EAuthTokenState_Denied\x10\x04\x12\x1f\n\x1bk_EAuthTokenState_LoggedOut\x10\x05\x12\x1e\n\x1ak_EAuthTokenState_Consumed\x10\x06\x12\x1d\n\x19k_EAuthTokenState_Revoked\x10\x63*\xaf\x02\n\x16\x45\x41uthTokenRevokeAction\x12\x1c\n\x18k_EAuthTokenRevokeLogout\x10\x00\x12\x1f\n\x1bk_EAuthTokenRevokePermanent\x10\x01\x12\x1e\n\x1ak_EAuthTokenRevokeReplaced\x10\x02\x12\x1d\n\x19k_EAuthTokenRevokeSupport\x10\x03\x12\x1d\n\x19k_EAuthTokenRevokeConsume\x10\x04\x12)\n%k_EAuthTokenRevokeNonRememberedLogout\x10\x05\x12,\n(k_EAuthTokenRevokeNonRememberedPermanent\x10\x06\x12\x1f\n\x1bk_EAuthTokenRevokeAutomatic\x10\x07\x32\x87\x0f\n\x0e\x41uthentication\x12~\n\x17GetPasswordRSAPublicKey\x12\x30.CAuthentication_GetPasswordRSAPublicKey_Request\x1a\x31.CAuthentication_GetPasswordRSAPublicKey_Response\x12x\n\x15\x42\x65ginAuthSessionViaQR\x12..CAuthentication_BeginAuthSessionViaQR_Request\x1a/.CAuthentication_BeginAuthSessionViaQR_Response\x12\x93\x01\n\x1e\x42\x65ginAuthSessionViaCredentials\x12\x37.CAuthentication_BeginAuthSessionViaCredentials_Request\x1a\x38.CAuthentication_BeginAuthSessionViaCredentials_Response\x12x\n\x15PollAuthSessionStatus\x12..CAuthentication_PollAuthSessionStatus_Request\x1a/.CAuthentication_PollAuthSessionStatus_Response\x12o\n\x12GetAuthSessionInfo\x12+.CAuthentication_GetAuthSessionInfo_Request\x1a,.CAuthentication_GetAuthSessionInfo_Response\x12{\n\x16GetAuthSessionRiskInfo\x12/.CAuthentication_GetAuthSessionRiskInfo_Request\x1a\x30.CAuthentication_GetAuthSessionRiskInfo_Response\x12Y\n\x15NotifyRiskQuizResults\x12\x33.CAuthentication_NotifyRiskQuizResults_Notification\x1a\x0b.NoResponse\x12\xae\x01\n\'UpdateAuthSessionWithMobileConfirmation\x12@.CAuthentication_UpdateAuthSessionWithMobileConfirmation_Request\x1a\x41.CAuthentication_UpdateAuthSessionWithMobileConfirmation_Response\x12\xa2\x01\n#UpdateAuthSessionWithSteamGuardCode\x12<.CAuthentication_UpdateAuthSessionWithSteamGuardCode_Request\x1a=.CAuthentication_UpdateAuthSessionWithSteamGuardCode_Response\x12\x86\x01\n\x19GenerateAccessTokenForApp\x12\x33.CAuthentication_AccessToken_GenerateForApp_Request\x1a\x34.CAuthentication_AccessToken_GenerateForApp_Response\x12t\n\x0f\x45numerateTokens\x12/.CAuthentication_RefreshToken_Enumerate_Request\x1a\x30.CAuthentication_RefreshToken_Enumerate_Response\x12\x84\x01\n\x19GetAuthSessionsForAccount\x12\x32.CAuthentication_GetAuthSessionsForAccount_Request\x1a\x33.CAuthentication_GetAuthSessionsForAccount_Response\x12u\n\x14MigrateMobileSession\x12-.CAuthentication_MigrateMobileSession_Request\x1a..CAuthentication_MigrateMobileSession_Response\x12\\\n\x0bRevokeToken\x12%.CAuthentication_Token_Revoke_Request\x1a&.CAuthentication_Token_Revoke_Response\x12q\n\x12RevokeRefreshToken\x12,.CAuthentication_RefreshToken_Revoke_Request\x1a-.CAuthentication_RefreshToken_Revoke_Response2\xa1\x05\n\x15\x41uthenticationSupport\x12\x98\x01\n\x1bQueryRefreshTokensByAccount\x12;.CAuthenticationSupport_QueryRefreshTokensByAccount_Request\x1a<.CAuthenticationSupport_QueryRefreshTokensByAccount_Response\x12\x86\x01\n\x15QueryRefreshTokenByID\x12\x35.CAuthenticationSupport_QueryRefreshTokenByID_Request\x1a\x36.CAuthenticationSupport_QueryRefreshTokenByID_Response\x12h\n\x0bRevokeToken\x12+.CAuthenticationSupport_RevokeToken_Request\x1a,.CAuthenticationSupport_RevokeToken_Response\x12t\n\x0fGetTokenHistory\x12/.CAuthenticationSupport_GetTokenHistory_Request\x1a\x30.CAuthenticationSupport_GetTokenHistory_Response\x12\x83\x01\n\x14MarkTokenCompromised\x12\x34.CAuthenticationSupport_MarkTokenCompromised_Request\x1a\x35.CAuthenticationSupport_MarkTokenCompromised_Response2\xc8\x01\n\x0b\x43loudGaming\x12T\n\x0b\x43reateNonce\x12!.CCloudGaming_CreateNonce_Request\x1a\".CCloudGaming_CreateNonce_Response\x12\x63\n\x10GetTimeRemaining\x12&.CCloudGaming_GetTimeRemaining_Request\x1a\'.CCloudGaming_GetTimeRemaining_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_auth_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _EAUTHTOKENPLATFORMTYPE._serialized_start=8125
  _EAUTHTOKENPLATFORMTYPE._serialized_end=8310
  _EAUTHTOKENAPPTYPE._serialized_start=8313
  _EAUTHTOKENAPPTYPE._serialized_end=8446
  _EAUTHSESSIONGUARDTYPE._serialized_start=8449
  _EAUTHSESSIONGUARDTYPE._serialized_end=8806
  _EAUTHSESSIONSECURITYHISTORY._serialized_start=8809
  _EAUTHSESSIONSECURITYHISTORY._serialized_end=8981
  _ETOKENRENEWALTYPE._serialized_start=8983
  _ETOKENRENEWALTYPE._serialized_end=9063
  _EAUTHENTICATIONTYPE._serialized_start=9066
  _EAUTHENTICATIONTYPE._serialized_end=9271
  _EAUTHTOKENSTATE._serialized_start=9274
  _EAUTHTOKENSTATE._serialized_end=9538
  _EAUTHTOKENREVOKEACTION._serialized_start=9541
  _EAUTHTOKENREVOKEACTION._serialized_end=9844
  _CAUTHENTICATION_GETPASSWORDRSAPUBLICKEY_REQUEST._serialized_start=101
  _CAUTHENTICATION_GETPASSWORDRSAPUBLICKEY_REQUEST._serialized_end=172
  _CAUTHENTICATION_GETPASSWORDRSAPUBLICKEY_RESPONSE._serialized_start=174
  _CAUTHENTICATION_GETPASSWORDRSAPUBLICKEY_RESPONSE._serialized_end=289
  _CAUTHENTICATION_DEVICEDETAILS._serialized_start=292
  _CAUTHENTICATION_DEVICEDETAILS._serialized_end=589
  _CAUTHENTICATION_BEGINAUTHSESSIONVIAQR_REQUEST._serialized_start=592
  _CAUTHENTICATION_BEGINAUTHSESSIONVIAQR_REQUEST._serialized_end=836
  _CAUTHENTICATION_ALLOWEDCONFIRMATION._serialized_start=839
  _CAUTHENTICATION_ALLOWEDCONFIRMATION._serialized_end=988
  _CAUTHENTICATION_BEGINAUTHSESSIONVIAQR_RESPONSE._serialized_start=991
  _CAUTHENTICATION_BEGINAUTHSESSIONVIAQR_RESPONSE._serialized_end=1205
  _CAUTHENTICATION_BEGINAUTHSESSIONVIACREDENTIALS_REQUEST._serialized_start=1208
  _CAUTHENTICATION_BEGINAUTHSESSIONVIACREDENTIALS_REQUEST._serialized_end=1702
  _CAUTHENTICATION_BEGINAUTHSESSIONVIACREDENTIALS_RESPONSE._serialized_start=1705
  _CAUTHENTICATION_BEGINAUTHSESSIONVIACREDENTIALS_RESPONSE._serialized_end=1988
  _CAUTHENTICATION_POLLAUTHSESSIONSTATUS_REQUEST._serialized_start=1990
  _CAUTHENTICATION_POLLAUTHSESSIONSTATUS_REQUEST._serialized_end=2101
  _CAUTHENTICATION_POLLAUTHSESSIONSTATUS_RESPONSE._serialized_start=2104
  _CAUTHENTICATION_POLLAUTHSESSIONSTATUS_RESPONSE._serialized_end=2356
  _CAUTHENTICATION_GETAUTHSESSIONINFO_REQUEST._serialized_start=2358
  _CAUTHENTICATION_GETAUTHSESSIONINFO_REQUEST._serialized_end=2421
  _CAUTHENTICATION_GETAUTHSESSIONINFO_RESPONSE._serialized_start=2424
  _CAUTHENTICATION_GETAUTHSESSIONINFO_RESPONSE._serialized_end=3000
  _CAUTHENTICATION_GETAUTHSESSIONRISKINFO_REQUEST._serialized_start=3002
  _CAUTHENTICATION_GETAUTHSESSIONRISKINFO_REQUEST._serialized_end=3087
  _CAUTHENTICATION_GETAUTHSESSIONRISKINFO_RESPONSE._serialized_start=3090
  _CAUTHENTICATION_GETAUTHSESSIONRISKINFO_RESPONSE._serialized_end=3301
  _CAUTHENTICATION_NOTIFYRISKQUIZRESULTS_NOTIFICATION._serialized_start=3304
  _CAUTHENTICATION_NOTIFYRISKQUIZRESULTS_NOTIFICATION._serialized_end=3584
  _CAUTHENTICATION_NOTIFYRISKQUIZRESULTS_NOTIFICATION_RISKQUIZRESULTS._serialized_start=3515
  _CAUTHENTICATION_NOTIFYRISKQUIZRESULTS_NOTIFICATION_RISKQUIZRESULTS._serialized_end=3584
  _CAUTHENTICATION_UPDATEAUTHSESSIONWITHMOBILECONFIRMATION_REQUEST._serialized_start=3587
  _CAUTHENTICATION_UPDATEAUTHSESSIONWITHMOBILECONFIRMATION_REQUEST._serialized_end=3825
  _CAUTHENTICATION_UPDATEAUTHSESSIONWITHMOBILECONFIRMATION_RESPONSE._serialized_start=3827
  _CAUTHENTICATION_UPDATEAUTHSESSIONWITHMOBILECONFIRMATION_RESPONSE._serialized_end=3893
  _CAUTHENTICATION_UPDATEAUTHSESSIONWITHSTEAMGUARDCODE_REQUEST._serialized_start=3896
  _CAUTHENTICATION_UPDATEAUTHSESSIONWITHSTEAMGUARDCODE_REQUEST._serialized_end=4083
  _CAUTHENTICATION_UPDATEAUTHSESSIONWITHSTEAMGUARDCODE_RESPONSE._serialized_start=4085
  _CAUTHENTICATION_UPDATEAUTHSESSIONWITHSTEAMGUARDCODE_RESPONSE._serialized_end=4178
  _CAUTHENTICATION_ACCESSTOKEN_GENERATEFORAPP_REQUEST._serialized_start=4181
  _CAUTHENTICATION_ACCESSTOKEN_GENERATEFORAPP_REQUEST._serialized_end=4341
  _CAUTHENTICATION_ACCESSTOKEN_GENERATEFORAPP_RESPONSE._serialized_start=4343
  _CAUTHENTICATION_ACCESSTOKEN_GENERATEFORAPP_RESPONSE._serialized_end=4441
  _CAUTHENTICATION_REFRESHTOKEN_ENUMERATE_REQUEST._serialized_start=4443
  _CAUTHENTICATION_REFRESHTOKEN_ENUMERATE_REQUEST._serialized_end=4523
  _CAUTHENTICATION_REFRESHTOKEN_ENUMERATE_RESPONSE._serialized_start=4526
  _CAUTHENTICATION_REFRESHTOKEN_ENUMERATE_RESPONSE._serialized_end=5432
  _CAUTHENTICATION_REFRESHTOKEN_ENUMERATE_RESPONSE_TOKENUSAGEEVENT._serialized_start=4701
  _CAUTHENTICATION_REFRESHTOKEN_ENUMERATE_RESPONSE_TOKENUSAGEEVENT._serialized_end=4822
  _CAUTHENTICATION_REFRESHTOKEN_ENUMERATE_RESPONSE_REFRESHTOKENDESCRIPTION._serialized_start=4825
  _CAUTHENTICATION_REFRESHTOKEN_ENUMERATE_RESPONSE_REFRESHTOKENDESCRIPTION._serialized_end=5432
  _CAUTHENTICATION_GETAUTHSESSIONSFORACCOUNT_REQUEST._serialized_start=5434
  _CAUTHENTICATION_GETAUTHSESSIONSFORACCOUNT_REQUEST._serialized_end=5485
  _CAUTHENTICATION_GETAUTHSESSIONSFORACCOUNT_RESPONSE._serialized_start=5487
  _CAUTHENTICATION_GETAUTHSESSIONSFORACCOUNT_RESPONSE._serialized_end=5559
  _CAUTHENTICATION_MIGRATEMOBILESESSION_REQUEST._serialized_start=5561
  _CAUTHENTICATION_MIGRATEMOBILESESSION_REQUEST._serialized_end=5658
  _CAUTHENTICATION_MIGRATEMOBILESESSION_RESPONSE._serialized_start=5660
  _CAUTHENTICATION_MIGRATEMOBILESESSION_RESPONSE._serialized_end=5752
  _CAUTHENTICATION_TOKEN_REVOKE_REQUEST._serialized_start=5755
  _CAUTHENTICATION_TOKEN_REVOKE_REQUEST._serialized_end=5885
  _CAUTHENTICATION_TOKEN_REVOKE_RESPONSE._serialized_start=5887
  _CAUTHENTICATION_TOKEN_REVOKE_RESPONSE._serialized_end=5926
  _CAUTHENTICATION_REFRESHTOKEN_REVOKE_REQUEST._serialized_start=5929
  _CAUTHENTICATION_REFRESHTOKEN_REVOKE_REQUEST._serialized_end=6105
  _CAUTHENTICATION_REFRESHTOKEN_REVOKE_RESPONSE._serialized_start=6107
  _CAUTHENTICATION_REFRESHTOKEN_REVOKE_RESPONSE._serialized_end=6153
  _CAUTHENTICATIONSUPPORT_QUERYREFRESHTOKENSBYACCOUNT_REQUEST._serialized_start=6155
  _CAUTHENTICATIONSUPPORT_QUERYREFRESHTOKENSBYACCOUNT_REQUEST._serialized_end=6264
  _CSUPPORTREFRESHTOKENDESCRIPTION._serialized_start=6267
  _CSUPPORTREFRESHTOKENDESCRIPTION._serialized_end=6869
  _CSUPPORTREFRESHTOKENDESCRIPTION_TOKENUSAGEEVENT._serialized_start=6764
  _CSUPPORTREFRESHTOKENDESCRIPTION_TOKENUSAGEEVENT._serialized_end=6869
  _CAUTHENTICATIONSUPPORT_QUERYREFRESHTOKENSBYACCOUNT_RESPONSE._serialized_start=6872
  _CAUTHENTICATIONSUPPORT_QUERYREFRESHTOKENSBYACCOUNT_RESPONSE._serialized_end=7017
  _CAUTHENTICATIONSUPPORT_QUERYREFRESHTOKENBYID_REQUEST._serialized_start=7019
  _CAUTHENTICATIONSUPPORT_QUERYREFRESHTOKENBYID_REQUEST._serialized_end=7091
  _CAUTHENTICATIONSUPPORT_QUERYREFRESHTOKENBYID_RESPONSE._serialized_start=7093
  _CAUTHENTICATIONSUPPORT_QUERYREFRESHTOKENBYID_RESPONSE._serialized_end=7206
  _CAUTHENTICATIONSUPPORT_REVOKETOKEN_REQUEST._serialized_start=7208
  _CAUTHENTICATIONSUPPORT_REVOKETOKEN_REQUEST._serialized_end=7287
  _CAUTHENTICATIONSUPPORT_REVOKETOKEN_RESPONSE._serialized_start=7289
  _CAUTHENTICATIONSUPPORT_REVOKETOKEN_RESPONSE._serialized_end=7334
  _CAUTHENTICATIONSUPPORT_GETTOKENHISTORY_REQUEST._serialized_start=7336
  _CAUTHENTICATIONSUPPORT_GETTOKENHISTORY_REQUEST._serialized_end=7402
  _CSUPPORTREFRESHTOKENAUDIT._serialized_start=7404
  _CSUPPORTREFRESHTOKENAUDIT._serialized_end=7504
  _CAUTHENTICATIONSUPPORT_GETTOKENHISTORY_RESPONSE._serialized_start=7506
  _CAUTHENTICATIONSUPPORT_GETTOKENHISTORY_RESPONSE._serialized_end=7600
  _CAUTHENTICATIONSUPPORT_MARKTOKENCOMPROMISED_REQUEST._serialized_start=7602
  _CAUTHENTICATIONSUPPORT_MARKTOKENCOMPROMISED_REQUEST._serialized_end=7690
  _CAUTHENTICATIONSUPPORT_MARKTOKENCOMPROMISED_RESPONSE._serialized_start=7692
  _CAUTHENTICATIONSUPPORT_MARKTOKENCOMPROMISED_RESPONSE._serialized_end=7746
  _CCLOUDGAMING_CREATENONCE_REQUEST._serialized_start=7748
  _CCLOUDGAMING_CREATENONCE_REQUEST._serialized_end=7815
  _CCLOUDGAMING_CREATENONCE_RESPONSE._serialized_start=7817
  _CCLOUDGAMING_CREATENONCE_RESPONSE._serialized_end=7883
  _CCLOUDGAMING_GETTIMEREMAINING_REQUEST._serialized_start=7885
  _CCLOUDGAMING_GETTIMEREMAINING_REQUEST._serialized_end=7962
  _CCLOUDGAMING_TIMEREMAINING._serialized_start=7964
  _CCLOUDGAMING_TIMEREMAINING._serialized_end=8034
  _CCLOUDGAMING_GETTIMEREMAINING_RESPONSE._serialized_start=8036
  _CCLOUDGAMING_GETTIMEREMAINING_RESPONSE._serialized_end=8122
  _AUTHENTICATION._serialized_start=9847
  _AUTHENTICATION._serialized_end=11774
  _AUTHENTICATIONSUPPORT._serialized_start=11777
  _AUTHENTICATIONSUPPORT._serialized_end=12450
  _CLOUDGAMING._serialized_start=12453
  _CLOUDGAMING._serialized_end=12653
_builder.BuildServices(DESCRIPTOR, 'steammessages_auth_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_friendmessages.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"steammessages_friendmessages.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\xf3\x01\n)CFriendMessages_GetRecentMessages_Request\x12\x10\n\x08steamid1\x18\x01 \x01(\x06\x12\x10\n\x08steamid2\x18\x02 \x01(\x06\x12\r\n\x05\x63ount\x18\x03 \x01(\r\x12 \n\x18most_recent_conversation\x18\x04 \x01(\x08\x12\x1a\n\x12rtime32_start_time\x18\x05 \x01(\x07\x12\x15\n\rbbcode_format\x18\x06 \x01(\x08\x12\x15\n\rstart_ordinal\x18\x07 \x01(\r\x12\x11\n\ttime_last\x18\x08 \x01(\r\x12\x14\n\x0cordinal_last\x18\t \x01(\r\"\xcf\x03\n*CFriendMessages_GetRecentMessages_Response\x12K\n\x08messages\x18\x01 \x03(\x0b\x32\x39.CFriendMessages_GetRecentMessages_Response.FriendMessage\x12\x16\n\x0emore_available\x18\x04 \x01(\x08\x1a\xbb\x02\n\rFriendMessage\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x11\n\ttimestamp\x18\x02 \x01(\r\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0f\n\x07ordinal\x18\x04 \x01(\r\x12\\\n\treactions\x18\x05 \x03(\x0b\x32I.CFriendMessages_GetRecentMessages_Response.FriendMessage.MessageReaction\x1a\x83\x01\n\x0fMessageReaction\x12L\n\rreaction_type\x18\x01 \x01(\x0e\x32\x15.EMessageReactionType:\x1ek_EMessageReactionType_Invalid\x12\x10\n\x08reaction\x18\x02 \x01(\t\x12\x10\n\x08reactors\x18\x03 \x03(\r\"s\n1CFriendsMessages_GetActiveMessageSessions_Request\x12\x19\n\x11lastmessage_since\x18\x01 \x01(\r\x12#\n\x1bonly_sessions_with_messages\x18\x02 \x01(\x08\"\xa4\x02\n2CFriendsMessages_GetActiveMessageSessions_Response\x12\x62\n\x10message_sessions\x18\x01 \x03(\x0b\x32H.CFriendsMessages_GetActiveMessageSessions_Response.FriendMessageSession\x12\x11\n\ttimestamp\x18\x02 \x01(\r\x1aw\n\x14\x46riendMessageSession\x12\x18\n\x10\x61\x63\x63ountid_friend\x18\x01 \x01(\r\x12\x14\n\x0clast_message\x18\x02 \x01(\r\x12\x11\n\tlast_view\x18\x03 \x01(\r\x12\x1c\n\x14unread_message_count\x18\x04 \x01(\r\"\xc2\x01\n#CFriendMessages_SendMessage_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x17\n\x0f\x63hat_entry_type\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x17\n\x0f\x63ontains_bbcode\x18\x04 \x01(\x08\x12\x16\n\x0e\x65\x63ho_to_sender\x18\x05 \x01(\x08\x12\x14\n\x0clow_priority\x18\x06 \x01(\x08\x12\x19\n\x11\x63lient_message_id\x18\x08 \x01(\t\"\x8c\x01\n$CFriendMessages_SendMessage_Response\x12\x18\n\x10modified_message\x18\x01 \x01(\t\x12\x18\n\x10server_timestamp\x18\x02 \x01(\r\x12\x0f\n\x07ordinal\x18\x03 \x01(\r\x12\x1f\n\x17message_without_bb_code\x18\x04 \x01(\t\"U\n\'CFriendMessages_AckMessage_Notification\x12\x17\n\x0fsteamid_partner\x18\x01 \x01(\x06\x12\x11\n\ttimestamp\x18\x02 \x01(\r\"<\n)CFriendMessages_IsInFriendsUIBeta_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"e\n*CFriendMessages_IsInFriendsUIBeta_Response\x12\x1b\n\x13online_in_friendsui\x18\x01 \x01(\x08\x12\x1a\n\x12has_used_friendsui\x18\x02 \x01(\x08\"\xdb\x01\n-CFriendMessages_UpdateMessageReaction_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x18\n\x10server_timestamp\x18\x02 \x01(\r\x12\x0f\n\x07ordinal\x18\x03 \x01(\r\x12L\n\rreaction_type\x18\x04 \x01(\x0e\x32\x15.EMessageReactionType:\x1ek_EMessageReactionType_Invalid\x12\x10\n\x08reaction\x18\x05 \x01(\t\x12\x0e\n\x06is_add\x18\x06 \x01(\x08\"B\n.CFriendMessages_UpdateMessageReaction_Response\x12\x10\n\x08reactors\x18\x01 \x03(\r\"\x86\x02\n,CFriendMessages_IncomingMessage_Notification\x12\x16\n\x0esteamid_friend\x18\x01 \x01(\x06\x12\x17\n\x0f\x63hat_entry_type\x18\x02 \x01(\x05\x12\x1c\n\x14\x66rom_limited_account\x18\x03 \x01(\x08\x12\x0f\n\x07message\x18\x04 \x01(\t\x12 \n\x18rtime32_server_timestamp\x18\x05 \x01(\x07\x12\x0f\n\x07ordinal\x18\x06 \x01(\r\x12\x12\n\nlocal_echo\x18\x07 \x01(\x08\x12\x19\n\x11message_no_bbcode\x18\x08 \x01(\t\x12\x14\n\x0clow_priority\x18\t \x01(\x08\"\xf2\x01\n,CFriendMessages_MessageReaction_Notification\x12\x16\n\x0esteamid_friend\x18\x01 \x01(\x06\x12\x18\n\x10server_timestamp\x18\x02 \x01(\r\x12\x0f\n\x07ordinal\x18\x03 \x01(\r\x12\x0f\n\x07reactor\x18\x04 \x01(\x06\x12L\n\rreaction_type\x18\x05 \x01(\x0e\x32\x15.EMessageReactionType:\x1ek_EMessageReactionType_Invalid\x12\x10\n\x08reaction\x18\x06 \x01(\t\x12\x0e\n\x06is_add\x18\x07 \x01(\x08*\x83\x01\n\x14\x45MessageReactionType\x12\"\n\x1ek_EMessageReactionType_Invalid\x10\x00\x12#\n\x1fk_EMessageReactionType_Emoticon\x10\x01\x12\"\n\x1ek_EMessageReactionType_Sticker\x10\x02\x32\x8d\x05\n\x0e\x46riendMessages\x12l\n\x11GetRecentMessages\x12*.CFriendMessages_GetRecentMessages_Request\x1a+.CFriendMessages_GetRecentMessages_Response\x12\x83\x01\n\x18GetActiveMessageSessions\x12\x32.CFriendsMessages_GetActiveMessageSessions_Request\x1a\x33.CFriendsMessages_GetActiveMessageSessions_Response\x12Z\n\x0bSendMessage\x12$.CFriendMessages_SendMessage_Request\x1a%.CFriendMessages_SendMessage_Response\x12\x43\n\nAckMessage\x12(.CFriendMessages_AckMessage_Notification\x1a\x0b.NoResponse\x12l\n\x11IsInFriendsUIBeta\x12*.CFriendMessages_IsInFriendsUIBeta_Request\x1a+.CFriendMessages_IsInFriendsUIBeta_Response\x12x\n\x15UpdateMessageReaction\x12..CFriendMessages_UpdateMessageReaction_Request\x1a/.CFriendMessages_UpdateMessageReaction_Response2\x89\x02\n\x14\x46riendMessagesClient\x12M\n\x0fIncomingMessage\x12-.CFriendMessages_IncomingMessage_Notification\x1a\x0b.NoResponse\x12M\n\x14NotifyAckMessageEcho\x12(.CFriendMessages_AckMessage_Notification\x1a\x0b.NoResponse\x12M\n\x0fMessageReaction\x12-.CFriendMessages_MessageReaction_Notification\x1a\x0b.NoResponse\x1a\x04\xc0\xb5\x18\x02\x42\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_friendmessages_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _FRIENDMESSAGESCLIENT._options = None
  _FRIENDMESSAGESCLIENT._serialized_options = b'\300\265\030\002'
  _EMESSAGEREACTIONTYPE._serialized_start=2615
  _EMESSAGEREACTIONTYPE._serialized_end=2746
  _CFRIENDMESSAGES_GETRECENTMESSAGES_REQUEST._serialized_start=99
  _CFRIENDMESSAGES_GETRECENTMESSAGES_REQUEST._serialized_end=342
  _CFRIENDMESSAGES_GETRECENTMESSAGES_RESPONSE._serialized_start=345
  _CFRIENDMESSAGES_GETRECENTMESSAGES_RESPONSE._serialized_end=808
  _CFRIENDMESSAGES_GETRECENTMESSAGES_RESPONSE_FRIENDMESSAGE._serialized_start=493
  _CFRIENDMESSAGES_GETRECENTMESSAGES_RESPONSE_FRIENDMESSAGE._serialized_end=808
  _CFRIENDMESSAGES_GETRECENTMESSAGES_RESPONSE_FRIENDMESSAGE_MESSAGEREACTION._serialized_start=677
  _CFRIENDMESSAGES_GETRECENTMESSAGES_RESPONSE_FRIENDMESSAGE_MESSAGEREACTION._serialized_end=808
  _CFRIENDSMESSAGES_GETACTIVEMESSAGESESSIONS_REQUEST._serialized_start=810
  _CFRIENDSMESSAGES_GETACTIVEMESSAGESESSIONS_REQUEST._serialized_end=925
  _CFRIENDSMESSAGES_GETACTIVEMESSAGESESSIONS_RESPONSE._serialized_start=928
  _CFRIENDSMESSAGES_GETACTIVEMESSAGESESSIONS_RESPONSE._serialized_end=1220
  _CFRIENDSMESSAGES_GETACTIVEMESSAGESESSIONS_RESPONSE_FRIENDMESSAGESESSION._serialized_start=1101
  _CFRIENDSMESSAGES_GETACTIVEMESSAGESESSIONS_RESPONSE_FRIENDMESSAGESESSION._serialized_end=1220
  _CFRIENDMESSAGES_SENDMESSAGE_REQUEST._serialized_start=1223
  _CFRIENDMESSAGES_SENDMESSAGE_REQUEST._serialized_end=1417
  _CFRIENDMESSAGES_SENDMESSAGE_RESPONSE._serialized_start=1420
  _CFRIENDMESSAGES_SENDMESSAGE_RESPONSE._serialized_end=1560
  _CFRIENDMESSAGES_ACKMESSAGE_NOTIFICATION._serialized_start=1562
  _CFRIENDMESSAGES_ACKMESSAGE_NOTIFICATION._serialized_end=1647
  _CFRIENDMESSAGES_ISINFRIENDSUIBETA_REQUEST._serialized_start=1649
  _CFRIENDMESSAGES_ISINFRIENDSUIBETA_REQUEST._serialized_end=1709
  _CFRIENDMESSAGES_ISINFRIENDSUIBETA_RESPONSE._serialized_start=1711
  _CFRIENDMESSAGES_ISINFRIENDSUIBETA_RESPONSE._serialized_end=1812
  _CFRIENDMESSAGES_UPDATEMESSAGEREACTION_REQUEST._serialized_start=1815
  _CFRIENDMESSAGES_UPDATEMESSAGEREACTION_REQUEST._serialized_end=2034
  _CFRIENDMESSAGES_UPDATEMESSAGEREACTION_RESPONSE._serialized_start=2036
  _CFRIENDMESSAGES_UPDATEMESSAGEREACTION_RESPONSE._serialized_end=2102
  _CFRIENDMESSAGES_INCOMINGMESSAGE_NOTIFICATION._serialized_start=2105
  _CFRIENDMESSAGES_INCOMINGMESSAGE_NOTIFICATION._serialized_end=2367
  _CFRIENDMESSAGES_MESSAGEREACTION_NOTIFICATION._serialized_start=2370
  _CFRIENDMESSAGES_MESSAGEREACTION_NOTIFICATION._serialized_end=2612
  _FRIENDMESSAGES._serialized_start=2749
  _FRIENDMESSAGES._serialized_end=3402
  _FRIENDMESSAGESCLIENT._serialized_start=3405
  _FRIENDMESSAGESCLIENT._serialized_end=3670
_builder.BuildServices(DESCRIPTOR, 'steammessages_friendmessages_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_sitelicenseclient.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%steammessages_sitelicenseclient.proto\x1a\x18steammessages_base.proto\"Z\n\x12\x43MsgClientSiteInfo\x12\x0f\n\x07site_id\x18\x01 \x01(\x04\x12\x11\n\tsite_name\x18\x02 \x01(\t\x12 \n\x18\x61llow_cached_credentials\x18\x03 \x01(\x08\".\n\x1d\x43MsgClientSiteLicenseCheckout\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\";\n%CMsgClientSiteLicenseCheckoutResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\"7\n&CMsgClientSiteLicenseGetAvailableSeats\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"S\n.CMsgClientSiteLicenseGetAvailableSeatsResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\r\n\x05seats\x18\x02 \x01(\r\"*\n(CMsgClientSiteLicenseGetContentCacheInfo\"\x97\x01\n0CMsgClientSiteLicenseGetContentCacheInfoResponse\x12\x11\n\tuse_cache\x18\x01 \x01(\x08\x12\x14\n\x0cipv4_address\x18\x02 \x01(\r\x12\x13\n\x0bport_number\x18\x03 \x01(\r\x12\x11\n\tp2p_group\x18\x04 \x01(\r\x12\x12\n\nip_address\x18\x05 \x01(\tB\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_sitelicenseclient_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _CMSGCLIENTSITEINFO._serialized_start=67
  _CMSGCLIENTSITEINFO._serialized_end=157
  _CMSGCLIENTSITELICENSECHECKOUT._serialized_start=159
  _CMSGCLIENTSITELICENSECHECKOUT._serialized_end=205
  _CMSGCLIENTSITELICENSECHECKOUTRESPONSE._serialized_start=207
  _CMSGCLIENTSITELICENSECHECKOUTRESPONSE._serialized_end=266
  _CMSGCLIENTSITELICENSEGETAVAILABLESEATS._serialized_start=268
  _CMSGCLIENTSITELICENSEGETAVAILABLESEATS._serialized_end=323
  _CMSGCLIENTSITELICENSEGETAVAILABLESEATSRESPONSE._serialized_start=325
  _CMSGCLIENTSITELICENSEGETAVAILABLESEATSRESPONSE._serialized_end=408
  _CMSGCLIENTSITELICENSEGETCONTENTCACHEINFO._serialized_start=410
  _CMSGCLIENTSITELICENSEGETCONTENTCACHEINFO._serialized_end=452
  _CMSGCLIENTSITELICENSEGETCONTENTCACHEINFORESPONSE._serialized_start=455
  _CMSGCLIENTSITELICENSEGETCONTENTCACHEINFORESPONSE._serialized_end=606
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_unified_base.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n steammessages_unified_base.proto\x1a google/protobuf/descriptor.proto\"\x0c\n\nNoResponse*]\n\x13\x45ProtoExecutionSite\x12 \n\x1ck_EProtoExecutionSiteUnknown\x10\x00\x12$\n k_EProtoExecutionSiteSteamClient\x10\x02*e\n\x11\x45ProtoServiceType\x12$\n k_EProtoServiceTypeSteamMessages\x10\x00\x12*\n&k_EProtoServiceTypeVRGamepadUIMessages\x10\x01:>\n\x13message_description\x12\x1f.google.protobuf.MessageOptions\x18\xb8\x8e\x03 \x01(\t:D\n\x12\x66orce_emit_message\x12\x1f.google.protobuf.MessageOptions\x18\xea\x86\x03 \x01(\x08:\x05\x66\x61lse:4\n\x0b\x64\x65scription\x12\x1d.google.protobuf.FieldOptions\x18\xd0\x86\x03 \x01(\t:>\n\x13service_description\x12\x1f.google.protobuf.ServiceOptions\x18\xd0\x86\x03 \x01(\t:u\n\x16service_execution_site\x12\x1f.google.protobuf.ServiceOptions\x18\xd8\x86\x03 \x01(\x0e\x32\x14.EProtoExecutionSite:\x1ck_EProtoExecutionSiteUnknown:m\n\x0cservice_type\x12\x1f.google.protobuf.ServiceOptions\x18\xe9\x86\x03 \x01(\x0e\x32\x12.EProtoServiceType: k_EProtoServiceTypeSteamMessages:D\n\x12\x66orce_emit_service\x12\x1f.google.protobuf.ServiceOptions\x18\xea\x86\x03 \x01(\x08:\x05\x66\x61lse:<\n\x12method_description\x12\x1e.google.protobuf.MethodOptions\x18\xd0\x86\x03 \x01(\t:8\n\x10\x65num_description\x12\x1c.google.protobuf.EnumOptions\x18\xd0\x86\x03 \x01(\t:C\n\x16\x65num_value_description\x12!.google.protobuf.EnumValueOptions\x18\xd0\x86\x03 \x01(\tB\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_unified_base_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(message_description)
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(force_emit_message)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(description)
  google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(service_description)
  google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(service_execution_site)
  google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(service_type)
  google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(force_emit_service)
  google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(method_description)
  google_dot_protobuf_dot_descriptor__pb2.EnumOptions.RegisterExtension(enum_description)
  google_dot_protobuf_dot_descriptor__pb2.EnumValueOptions.RegisterExtension(enum_value_description)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _EPROTOEXECUTIONSITE._serialized_start=84
  _EPROTOEXECUTIONSITE._serialized_end=177
  _EPROTOSERVICETYPE._serialized_start=179
  _EPROTOSERVICETYPE._serialized_end=280
  _NORESPONSE._serialized_start=70
  _NORESPONSE._serialized_end=82
# @@protoc_insertion_point(module_scope)
